@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: CreatorClient.cpp,v 1.35 2008-01-26 17:43:21 alriddoch Exp $
+// $Id$
 
 #include "Py_CreatorClient.h"
 
@@ -32,6 +32,7 @@ using Atlas::Objects::Root;
 using Atlas::Objects::Operation::Set;
 using Atlas::Objects::Operation::Look;
 using Atlas::Objects::Operation::Create;
+using Atlas::Objects::Operation::Delete;
 using Atlas::Objects::Operation::RootOperation;
 using Atlas::Objects::Entity::RootEntity;
 using Atlas::Objects::Entity::Anonymous;
@@ -40,7 +41,6 @@ using Atlas::Objects::smart_dynamic_cast;
 
 CreatorClient::CreatorClient(const std::string & id, long intId,
                              ClientConnection &c) :
-               Identified(id, intId),
                CharacterClient(id, intId, c)
 {
 }
@@ -162,8 +162,11 @@ LocatedEntity * CreatorClient::sendLook(const Operation & op)
         return NULL;
     }
     const std::string & resparents = res->getParents().front();
+    if (resparents == "unseen") {
+        return NULL;
+    }
     if (resparents != "sight") {
-        std::cerr << "Reply to look isn't sight" << std::endl << std::flush;
+        std::cerr << "Reply to look is " << resparents << " not sight" << std::endl << std::flush;
         return NULL;
     }
     if (res->getArgs().empty()) {
@@ -180,11 +183,27 @@ LocatedEntity * CreatorClient::sendLook(const Operation & op)
         return NULL;
     }
     const std::string & created_id = seen->getId();
-    std::cout << "Seen: " << created_id << std::endl << std::flush;
+    if (seen->hasAttrFlag(Atlas::Objects::PARENTS_FLAG)) {
+        std::cout << "Seen: " << seen->getParents().front()
+                  << "(" << created_id << ")" << std::endl << std::flush;
+    } else {
+        std::cout << "Seen: " << created_id << std::endl << std::flush;
+    }
     LocatedEntity * obj = m_map.updateAdd(seen, res->getSeconds());
     return obj;
 }
 
+void CreatorClient::del(const std::string & id)
+{
+    Delete op;
+    Anonymous ent;
+    ent->setId(id);
+    op->setArgs1(ent);
+    op->setFrom(getId());
+    op->setTo(id);
+    return send(op);
+}
+
 int CreatorClient::runScript(const std::string & package,
                              const std::string & function)
 {
