@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: client.cpp,v 1.31 2007-11-14 22:40:18 alriddoch Exp $
+// $Id$
 
 #include "ObserverClient.h"
 #include "ClientPropertyManager.h"
@@ -37,6 +37,21 @@ static void usage(const char * prgname)
               << std::endl << std::flush;
 }
 
+STRING_OPTION(server, "localhost", "client", "serverhost",
+              "Hostname of the server to connect to");
+
+STRING_OPTION(account, "admin", "client", "account",
+              "Account name to use to authenticate to the server");
+
+STRING_OPTION(password, "", "client", "password",
+              "Password to use to authenticate to the server");
+
+STRING_OPTION(package, "", "client", "package",
+              "Python package which contains the world initialisation code");
+
+STRING_OPTION(function, "", "client", "function",
+              "Python function to initialise the world");
+
 int main(int argc, char ** argv)
 {
     int config_status = loadConfig(argc, argv, USAGE_CLIENT); 
@@ -58,21 +73,6 @@ int main(int argc, char ** argv)
 
     assert(optind <= argc);
 
-    std::string server = "localhost";
-    readConfigItem("client", "serverhost", server);
-
-    std::string account = "admin";
-    readConfigItem("client", "account", account);
-
-    std::string password;
-    readConfigItem("client", "password", password);
-
-    std::string package;
-    readConfigItem("client", "package", package);
-
-    std::string function;
-    readConfigItem("client", "function", function);
-
     if (optind == (argc - 1)) {
         std::string arg(argv[optind]);
         std::string::size_type pos = arg.rfind(".");
@@ -96,6 +96,8 @@ int main(int argc, char ** argv)
         ObserverClient & observer = *new ObserverClient();
         observer.setServer(server);
         if (observer.setup(account, password) != 0) {
+            std::cerr << "ERROR: Connection failed."
+                      << std::endl << std::flush;
             return 1;
         }
         observer.load(package, function);
