@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Database.cpp,v 1.101 2008-04-28 17:26:09 alriddoch Exp $
+// $Id$
 
 #include "Database.h"
 
@@ -24,6 +24,7 @@
 #include "debug.h"
 #include "globals.h"
 #include "compose.hpp"
+#include "const.h"
 
 #include <Atlas/Message/MEncoder.h>
 #include <Atlas/Message/Element.h>
@@ -42,6 +43,7 @@
 using Atlas::Message::Element;
 using Atlas::Message::MapType;
 using Atlas::Objects::Root;
+using String::compose;
 
 typedef Atlas::Codecs::XML Serialiser;
 
@@ -104,8 +106,8 @@ int Database::createInstanceDatabase()
     std::string error_message;
 
     if (connect(CYPHESIS, error_message) != 0) {
-        log(ERROR, String::compose("Connection to master database failed: \n%1",
-                                   error_message));
+        log(ERROR, compose("Connection to master database failed: \n%1",
+                           error_message));
         return -1;
     }
 
@@ -113,11 +115,11 @@ int Database::createInstanceDatabase()
     if (::instance == CYPHESIS) {
         dbname = CYPHESIS;
     } else {
-        dbname = String::compose("%1_%2", CYPHESIS, ::instance);
+        dbname = compose("%1_%2", CYPHESIS, ::instance);
     }
     readConfigItem(::instance, "dbname", dbname);
 
-    if (!runCommandQuery(String::compose("CREATE DATABASE %1", dbname))) {
+    if (!runCommandQuery(compose("CREATE DATABASE %1", dbname))) {
         shutdownConnection();
         return -1;
     }
@@ -145,7 +147,7 @@ int Database::connect(const std::string & context, std::string & error_msg)
     if (context == CYPHESIS) {
         dbname = CYPHESIS;
     } else {
-        dbname = String::compose("%1_%2", CYPHESIS, ::instance);
+        dbname = compose("%1_%2", CYPHESIS, ::instance);
     }
     readConfigItem(context, "dbname", dbname);
     conninfos << "dbname=" << dbname << " ";
@@ -189,8 +191,8 @@ int Database::initConnection()
     std::string error_message;
 
     if (connect(::instance, error_message) != 0) {
-        log(ERROR, String::compose("Connection to database failed: \n%1",
-                                   error_message));
+        log(ERROR, compose("Connection to database failed: \n%1",
+                           error_message));
         return -1;
     }
 
@@ -205,7 +207,8 @@ bool Database::initRule(bool createTables)
 
     int status = 0;
     clearPendingQuery();
-    status = PQsendQuery(m_connection, "SELECT * FROM rules WHERE id = 'test' AND contents = 'test'");
+    status = PQsendQuery(m_connection, "SELECT * FROM rules WHERE "
+                                       "id = 'test' AND contents = 'test'");
     if (!status) {
         reportError();
         return false;
@@ -215,7 +218,12 @@ bool Database::initRule(bool createTables)
         debug(std::cout << "Rule table does not exist"
                         << std::endl << std::flush;);
         if (createTables) {
-            status = PQsendQuery(m_connection, "CREATE TABLE rules ( id varchar(80) PRIMARY KEY, ruleset varchar(32), contents text ) WITHOUT OIDS");
+            std::string query = compose("CREATE TABLE rules ( "
+                                        "id varchar(%1) PRIMARY KEY, "
+                                        "ruleset varchar(%1), "
+                                        "contents text ) "
+                                        "WITHOUT OIDS", consts::id_len);
+            status = PQsendQuery(m_connection, query.c_str());
             if (!status) {
                 reportError();
                 return false;
@@ -324,7 +332,18 @@ bool Database::encodeObject(const MapType & o,
     enc.streamMessageElement(o);
     codec.streamEnd();
 
-    data = str.str();
+    std::string raw = str.str();
+    char safe[raw.size() * 2 + 1];
+    int errcode;
+
+    PQescapeStringConn(m_connection, safe, raw.c_str(), raw.size(), &errcode);
+
+    if (errcode != 0) {
+        std::cerr << "ERROR: " << errcode << std::endl << std::flush;
+    }
+
+    data = safe;
+
     return true;
 }
 
@@ -629,34 +648,8 @@ bool Database::registerRelation(std::string & tablename,
 
     tablename = sourcetable + "_" + targettable;
 
-    std::string query = "SELECT * FROM ";
-    query += tablename;
-    query += " WHERE source = 0 AND target = 0";
-
-    std::string createquery = "CREATE TABLE ";
-    createquery += tablename;
-    if (kind == OneToOne || kind == ManyToOne) {
-        createquery += " (source integer UNIQUE REFERENCES ";
-    } else {
-        createquery += " (source integer REFERENCES ";
-    }
-    createquery += sourcetable;
-#if 0
-    // FIXME Referential integrity not supported on inherited tables.
-    if (kind == OneToOne || kind == OneToMany) {
-        createquery += " (id), target integer UNIQUE REFERENCES ";
-    } else {
-        createquery += " (id), target integer REFERENCES ";
-    }
-    createquery += targettable;
-    createquery += " (id))";
-#else
-    if (kind == OneToOne || kind == OneToMany) {
-        createquery += " (id), target integer UNIQUE) WITHOUT OIDS";
-    } else {
-        createquery += " (id), target integer) WITHOUT OIDS";
-    }
-#endif
+    std::string query = compose("SELECT * FROM %1 WHERE source = 0 "
+                                "AND target = 0", tablename);
 
     debug(std::cout << "QUERY: " << query << std::endl << std::flush;);
     clearPendingQuery();
@@ -676,9 +669,25 @@ bool Database::registerRelation(std::string & tablename,
         return true;
     }
 
-    debug(std::cout << "CREATE QUERY: " << createquery
+    query = "CREATE TABLE ";
+    query += tablename;
+    if (kind == OneToOne || kind == ManyToOne) {
+        query += " (source integer UNIQUE REFERENCES ";
+    } else {
+        query += " (source integer REFERENCES ";
+    }
+    query += sourcetable;
+    if (kind == OneToOne || kind == OneToMany) {
+        query += " (id), target integer UNIQUE REFERENCES ";
+    } else {
+        query += " (id), target integer REFERENCES ";
+    }
+    query += targettable;
+    query += " (id) ON DELETE CASCADE ) WITHOUT OIDS";
+
+    debug(std::cout << "CREATE QUERY: " << query
                     << std::endl << std::flush;);
-    if (!runCommandQuery(createquery)) {
+    if (!runCommandQuery(query)) {
         return false;
     }
     allTables.insert(tablename);
@@ -891,7 +900,7 @@ bool Database::updateSimpleRow(const std::string & name,
     return scheduleCommand(query);
 }
 
-bool Database::registerEntityIdGenerator()
+int Database::registerEntityIdGenerator()
 {
     assert(m_connection != 0);
 
@@ -900,7 +909,7 @@ bool Database::registerEntityIdGenerator()
     if (!status) {
         log(ERROR, "registerEntityIdGenerator(): Database query error.");
         reportError();
-        return false;
+        return -1;
     }
     if (!tuplesOk()) {
         debug(reportError(););
@@ -908,9 +917,9 @@ bool Database::registerEntityIdGenerator()
                         << std::endl << std::flush;);
     } else {
         debug(std::cout << "Sequence exists" << std::endl << std::flush;);
-        return true;
+        return 0;
     }
-    return runCommandQuery("CREATE SEQUENCE entity_ent_id_seq");
+    return runCommandQuery("CREATE SEQUENCE entity_ent_id_seq") ? 0 : -1;
 }
 
 long Database::newId(std::string & id)
@@ -945,265 +954,178 @@ long Database::newId(std::string & id)
     return forceIntegerId(id);
 }
 
-#if 0
-bool Database::registerEntityTable(const std::string & classname,
-                                   const MapType & row,
-                                   const std::string & parent)
-// TODO
-// row probably needs to be richer to provide a more detailed, and possibly
-// ordered description of each the columns required.
+int Database::registerEntityTable(const std::map<std::string, int> & chunks)
 {
-    if (m_connection == 0) {
-        log(CRITICAL, "Database connection is down. This is okay during tests");
-        return false;
-    }
+    assert(m_connection != 0);
 
-    if (entityTables.find(classname) != entityTables.end()) {
-        log(ERROR, String::compose("Attempt to register entity table \"%1\" "
-                                   "which is already registered.", classname));
-        return false;
-    }
-    if (!parent.empty()) {
-        if (entityTables.empty()) {
-            log(ERROR, "Registering non-root entity table when no root registered.");
-            debug(std::cerr << "Table for class " << classname
-                            << " cannot be non-root."
-                            << std::endl << std::flush;);
-            return false;
-        }
-        if (entityTables.find(parent) == entityTables.end()) {
-            log(ERROR, "Registering entity table with non existant parent.");
-            debug(std::cerr << "Table for class " << classname
-                            << " cannot have non-existant parent " << parent
-                            << std::endl << std::flush;);
-            return false;
-        }
-    } else if (!entityTables.empty()) {
-        log(ERROR, "Attempt to create root entity class table when one already registered.");
-        debug(std::cerr << "Table for class " << classname
-                        << " cannot be root." << std::endl << std::flush;);
-        return false;
-    }
-    // At this point we know the table request make sense.
-    entityTables[classname] = parent;
-    const std::string tablename = classname + "_ent";
-    // Check whether the table exists
-    std::string query = "SELECT * FROM ";
-    std::string createquery = "CREATE TABLE ";
-    query += tablename;
-    createquery += tablename;
-    if (!row.empty()) {
-        query += " WHERE ";
-    }
-    createquery += " (";
-    if (parent.empty()) {
-        createquery += "id integer UNIQUE PRIMARY KEY, ";
-    }
-    MapType::const_iterator Iend = row.end();
-    for (MapType::const_iterator I = row.begin(); I != Iend; ++I) {
-        if (I != row.begin()) {
-            query += " AND ";
-            createquery += ", ";
-        }
-        const std::string & column = I->first;
-        query += column;
-        createquery += column;
-        const Element & type = I->second;
-        if (type.isString()) {
-            query += " LIKE 'foo'";
-            int size = type.String().size();
-            if (size == 0) {
-                createquery += " text";
-            } else {
-                char buf[32];
-                snprintf(buf, 32, "%d", size);
-                createquery += " varchar(";
-                createquery += buf;
-                createquery += ")";
-            }
-        } else if (type.isInt()) {
-            if (type.asInt() == 0xb001) {
-                query += " = 't'";
-                createquery += " boolean";
-            } else {
-                query += " = 1";
-                createquery += " integer";
-            }
-        } else if (type.isFloat()) {
-            query += " = 1.0";
-            createquery += " float";
-        } else {
-            log(ERROR, "Illegal column type in database entity row");
-        }
-    }
-
-    debug(std::cout << "QUERY: " << query << std::endl << std::flush;);
     clearPendingQuery();
-    int status = PQsendQuery(m_connection, query.c_str());
+    int status = PQsendQuery(m_connection, "SELECT * FROM entities");
     if (!status) {
-        log(ERROR, "registerEntityTable(): Database query error.");
+        log(ERROR, "registerEntityIdGenerator(): Database query error.");
         reportError();
-        return false;
+        return -1;
     }
     if (!tuplesOk()) {
         debug(reportError(););
         debug(std::cout << "Table does not yet exist"
                         << std::endl << std::flush;);
     } else {
-        if (parent.empty()) {
-            allTables.insert(tablename);
-        }
+        allTables.insert("entities");
+        // FIXME Flush out the whole state of the databases, to ensure they
+        // don't clog up while we are testing.
+        // runCommandQuery("DELETE FROM properties");
+        // runCommandQuery(compose("DELETE FROM entities WHERE id!=%1",
+                                // consts::rootWorldIntId));
         debug(std::cout << "Table exists" << std::endl << std::flush;);
-        return true;
+        return 0;
     }
-    // create table
-    createquery += ")";
-    if (parent.empty()) {
-        createquery += " WITHOUT OIDS";
-    } else {
-        createquery += " INHERITS (";
-        createquery += parent;
-        createquery += "_ent)";
+    std::string query = compose("CREATE TABLE entities ("
+                                "id integer UNIQUE PRIMARY KEY, "
+                                "loc integer, "
+                                "type varchar(%1), "
+                                "seq integer", consts::id_len);
+    std::map<std::string, int>::const_iterator I = chunks.begin();
+    std::map<std::string, int>::const_iterator Iend = chunks.end();
+    for (; I != Iend; ++I) {
+        query += compose(", %1 varchar(1024)", I->first);
     }
-    debug(std::cout << "CREATE QUERY: " << createquery
-                    << std::endl << std::flush;);
-
-    bool ret = runCommandQuery(createquery);
-    if (ret && parent.empty()) {
-        allTables.insert(tablename);
-    }
-    return ret;
-}
-
-bool Database::createEntityRow(const std::string & classname,
-                               const std::string & id,
-                               const std::string & columns,
-                               const std::string & values)
-{
-    TableDict::const_iterator I = entityTables.find(classname);
-    if (I == entityTables.end()) {
-        log(ERROR, "Attempt to insert into entity table not registered.");
-        return false;
-    }
-    std::string query = "INSERT INTO ";
-    query += classname;
-    query += "_ent ( id, ";
-    query += columns;
-    query += " ) VALUES ( ";
-    query += id;
-    query += ", ";
-    query += values;
     query += ")";
-    debug(std::cout << "QUERY: " << query << std::endl << std::flush;);
+    if (!runCommandQuery(query)) {
+        return -1;
+    }
+    allTables.insert("entities");
+    query = compose("INSERT INTO entities VALUES (%1, null, 'world')",
+                    consts::rootWorldIntId);
+    if (!runCommandQuery(query)) {
+        return -1;
+    }
+    return 0;
+}
 
-    // return runCommandQuery(query);
+int Database::insertEntity(const std::string & id,
+                           const std::string & loc,
+                           const std::string & type,
+                           int seq,
+                           const std::string & value)
+{
+    std::string query = compose("INSERT INTO entities VALUES "
+                                "(%1, %2, '%3', %4, '%5')",
+                                id, loc, type, seq, value);
     return scheduleCommand(query);
 }
 
-bool Database::updateEntityRow(const std::string & classname,
-                               const std::string & id,
-                               const std::string & columns)
+int Database::updateEntity(const std::string & id,
+                           int seq,
+                           const std::string & value)
 {
-    if (columns.empty()) {
-        log(WARNING, "Update query passed to database with no columns.");
-        return false;
-    }
-    TableDict::const_iterator I = entityTables.find(classname);
-    if (I == entityTables.end()) {
-        log(ERROR, "Attempt to update entity table not registered.");
-        return false;
-    }
-    std::string query = "UPDATE ";
-    query += classname;
-    query += "_ent SET ";
-    query += columns;
-    query += " WHERE id='";
-    query += id;
-    query += "'";
-    debug(std::cout << "QUERY: " << query << std::endl << std::flush;);
-
+    std::string query = compose("UPDATE entities SET seq = %1, location = '%2'"
+                                " WHERE id = %3", seq, value, id);
     return scheduleCommand(query);
 }
 
-bool Database::removeEntityRow(const std::string & classname,
-                               const std::string & id)
+const DatabaseResult Database::selectEntities(const std::string & loc)
 {
-    TableDict::const_iterator I = entityTables.find(classname);
-    if (I == entityTables.end()) {
-        log(ERROR, "Attempt to remove from entity table not registered.");
-        return false;
-    }
-    std::string query = "DELETE FROM ";
-    query += classname;
-    query += "_ent WHERE id='";
-    query += id;
-    query += "'";
-    debug(std::cout << "QUERY: " << query << std::endl << std::flush;);
-
-    // return runCommandQuery(query);
-    return scheduleCommand(query);
-}
-
-const DatabaseResult Database::selectEntityRow(const std::string & id,
-                                               const std::string & classname)
-{
-    std::string table = (classname == "" ? "entity" : classname);
-    TableDict::const_iterator I = entityTables.find(classname);
-    if (I == entityTables.end()) {
-        log(ERROR, String::compose("Attempt to select from entity table \"%1\" "
-                                   "which is not registered.", classname));
-        return DatabaseResult(0);
-    }
-    std::string query = "SELECT * FROM ";
-    query += table;
-    query += "_ent WHERE id='";
-    query += id;
-    query += "'";
-
-    debug(std::cout << "Selecting on id = " << id << " ... " << std::flush;);
-
-    return runSimpleSelectQuery(query);
-}
-
-const DatabaseResult Database::selectOnlyByLoc(const std::string & loc,
-                                               const std::string & classname)
-{
-    TableDict::const_iterator I = entityTables.find(classname);
-    if (I == entityTables.end()) {
-        log(ERROR, String::compose("Attempt to select from entity table \"%1\" "
-                                   "which is not registered.", classname));
-        return DatabaseResult(0);
-    }
-
-    std::string query = "SELECT * FROM ONLY ";
-    query += classname;
-    query += "_ent WHERE loc";
-    if (loc.empty()) {
-        query += " is null";
-    } else {
-        query += "=";
-        query += loc;
-    }
-
-
-    return runSimpleSelectQuery(query);
-}
-
-const DatabaseResult Database::selectClassByLoc(const std::string & loc)
-{
-    std::string query = "SELECT id, class FROM entity_ent WHERE loc";
-    if (loc.empty()) {
-        query += " is null";
-    } else {
-        query += "=";
-        query += loc;
-    }
+    std::string query = compose("SELECT id, type, seq, location FROM entities"
+                                " WHERE loc = %1", loc);
 
     debug(std::cout << "Selecting on loc = " << loc << " ... " << std::flush;);
 
     return runSimpleSelectQuery(query);
 }
-#endif // 0
+
+int Database::dropEntity(long id)
+{
+    std::string query = compose("DELETE FROM properties WHERE id = '%1'", id);
+
+    scheduleCommand(query);
+
+    query = compose("DELETE FROM entities WHERE id = %1", id);
+
+    scheduleCommand(query);
+
+    return 0;
+}
+
+int Database::registerPropertyTable()
+{
+    assert(m_connection != 0);
+
+    clearPendingQuery();
+    int status = PQsendQuery(m_connection, "SELECT * FROM properties");
+    if (!status) {
+        log(ERROR, "registerPropertyIdGenerator(): Database query error.");
+        reportError();
+        return -1;
+    }
+    if (!tuplesOk()) {
+        debug(reportError(););
+        debug(std::cout << "Table does not yet exist"
+                        << std::endl << std::flush;);
+    } else {
+        allTables.insert("properties");
+        debug(std::cout << "Table exists" << std::endl << std::flush;);
+        return 0;
+    }
+    allTables.insert("properties");
+    std::string query = compose("CREATE TABLE properties ("
+                                "id integer REFERENCES entities "
+                                "ON DELETE CASCADE, "
+                                "name varchar(%1), "
+                                "value text)", consts::id_len);
+    if (!runCommandQuery(query)) {
+        reportError();
+        return -1;
+    }
+    query = "CREATE INDEX property_names on properties (name)";
+    if (!runCommandQuery(query)) {
+        reportError();
+        return -1;
+    }
+    return 0;
+}
+
+int Database::insertProperties(const std::string & id,
+                               const KeyValues & tuples)
+{
+    int first = 1;
+    std::string query("INSERT INTO properties VALUES ");
+    KeyValues::const_iterator I = tuples.begin();
+    KeyValues::const_iterator Iend = tuples.end();
+    for (; I != Iend; ++I) {
+        if (first) {
+            query += compose("(%1, '%2', '%3')", id, I->first, I->second);
+            first = 0;
+        } else {
+            query += compose(", (%1, '%2', '%3')", id, I->first, I->second);
+        }
+    }
+    return scheduleCommand(query);
+}
+
+const DatabaseResult Database::selectProperties(const std::string & id)
+{
+    std::string query = compose("SELECT name, value FROM properties"
+                                " WHERE id = %1", id);
+
+    debug(std::cout << "Selecting on id = " << id << " ... "
+                    << std::endl << std::flush;);
+
+    return runSimpleSelectQuery(query);
+}
+
+int Database::updateProperties(const std::string & id,
+                               const KeyValues & tuples)
+{
+    KeyValues::const_iterator I = tuples.begin();
+    KeyValues::const_iterator Iend = tuples.end();
+    for (; I != Iend; ++I) {
+        std::string query = compose("UPDATE properties SET value = '%3' WHERE"
+                                    " id=%1 AND name='%2'",
+                                    id, I->first, I->second);
+        scheduleCommand(query);
+    }
+    return 0;
+}
 
 #if 0
 // Interface for tables for sparse sequences or arrays of data. Terrain
@@ -1235,9 +1157,7 @@ bool Database::registerArrayTable(const std::string & name,
     query += " WHERE id = 0";
 
     createquery += name;
-    // FIXME This is a foreign key to an inherited table.
-    // Implement referential integrity once PostgreSQL works.
-    createquery += " (id integer NOT NULL";
+    createquery += " (id integer REFERENCES entities NOT NULL";
 
     indexquery += name;
     indexquery += "_point_idx on ";
@@ -1486,8 +1406,10 @@ void Database::queryComplete()
 
 bool Database::launchNewQuery()
 {
-    assert(m_connection != 0);
-
+    if (m_connection == 0) {
+        log(ERROR, "Can't launch new query while database is offline.");
+        return false;
+    }
     if (m_queryInProgress) {
         log(ERROR, "Launching new query when query is in progress");
         return false;
@@ -1549,12 +1471,11 @@ bool Database::clearPendingQuery()
 
 bool Database::runMaintainance(int command)
 {
-    // FIXME VACUUM and REINDEX tables from a common store
+    // VACUUM and REINDEX tables from a common store
     if ((command & MAINTAIN_REINDEX) == MAINTAIN_REINDEX) {
         std::string query("REINDEX TABLE ");
         TableSet::const_iterator Iend = allTables.end();
         for (TableSet::const_iterator I = allTables.begin(); I != Iend; ++I) {
-            debug(std::cout << (query + *I) << std::endl << std::flush;);
             scheduleCommand(query + *I);
         }
     }
@@ -1568,7 +1489,6 @@ bool Database::runMaintainance(int command)
         }
         TableSet::const_iterator Iend = allTables.end();
         for(TableSet::const_iterator I = allTables.begin(); I != Iend; ++I) {
-            debug(std::cout << (query + *I) << std::endl << std::flush;);
             scheduleCommand(query + *I);
         }
     }
