@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: PropertyFactory.h,v 1.9 2007-12-20 18:47:28 alriddoch Exp $
+// $Id$
 
 #ifndef COMMON_PROPERTY_FACTORY_H
 #define COMMON_PROPERTY_FACTORY_H
@@ -31,14 +31,14 @@ class PropertyKit {
     virtual ~PropertyKit();
 
     /// \brief Create a new Property instance
-    virtual PropertyBase * newProperty(Entity *) = 0;
+    virtual PropertyBase * newProperty() = 0;
 };
 
 /// \brief Factory template to create standard Property objects.
 template <class T>
 class PropertyFactory : public PropertyKit {
   public:
-    virtual PropertyBase * newProperty(Entity *);
+    virtual PropertyBase * newProperty();
 };
 
 #endif // COMMON_PROPERTY_FACTORY_H
