@@ -15,9 +15,9 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: custom.cpp,v 1.50 2008-03-26 01:34:16 alriddoch Exp $
+// $Id$
 
-#include "inheritance.h"
+#include "Inheritance.h"
 
 #include "Actuate.h"
 #include "Add.h"
