@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: globals.cpp,v 1.62 2008-04-28 17:26:09 alriddoch Exp $
+// $Id$
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -28,8 +28,6 @@
 #include "log.h"
 #include "compose.hpp"
 
-#include "modules/DateTime.h"
-
 #include <varconf/config.h>
 
 #include <algorithm>
@@ -41,12 +39,9 @@
 #include <cassert>
 
 const char * CYPHESIS = "cyphesis";
-const char * CLIENT = "client";
 const char * SLAVE = "slave";
 
 static const char * DEFAULT_RULESET = "mason";
-static const char * DEFAULT_CLIENT_SOCKET = "cyphesis.sock";
-static const char * DEFAULT_SLAVE_SOCKET = "cyslave.sock";
 static const char * DEFAULT_INSTANCE = "cyphesis";
 
 varconf::Config * global_conf = NULL;
@@ -54,21 +49,14 @@ std::string instance(DEFAULT_INSTANCE);
 std::string share_directory(DATADIR);
 std::string etc_directory(SYSCONFDIR);
 std::string var_directory(LOCALSTATEDIR);
-std::string client_socket_name(DEFAULT_CLIENT_SOCKET);
-std::string slave_socket_name(DEFAULT_SLAVE_SOCKET);
 std::string ruleset(DEFAULT_RULESET);
 bool exit_flag = false;
 bool daemon_flag = false;
-bool restricted_flag = false;
 bool database_flag = true;
-bool pvp_flag = false;
-bool pvp_offl_flag = false;
-int timeoffset = DateTime::spm() * DateTime::mph() * 9; // Morning
+int timeoffset = SPM * MPH * 9; // Morning
 int client_port_num = 6767;
-int slave_port_num = 6768;
-int peer_port_num = 6769;
-int dynamic_port_start = 6780;
-int dynamic_port_end = 6799;
+int dynamic_port_start = 6800;
+int dynamic_port_end = 6899;
 
 static const char * FALLBACK_LOCALSTATEDIR = "/var";
 
@@ -76,6 +64,7 @@ static const int S = USAGE_SERVER;
 static const int C = USAGE_CLIENT;
 static const int M = USAGE_CYCMD;
 static const int D = USAGE_DBASE;
+static const int P = USAGE_CYPYTHON;
 
 typedef struct {
     const char * section;
@@ -96,13 +85,9 @@ static const usage_data usage[] = {
     { CYPHESIS, "ruleset", "<name>", DEFAULT_RULESET, "Ruleset name", S|C|D },
     { CYPHESIS, "servername", "<name>", "<hostname>", "Published name of the server", S|C },
     { CYPHESIS, "tcpport", "<portnumber>", "6767", "Network listen port for client connections", S|C|M },
-    { CYPHESIS, "dynamic_port_start", "<portnumber>", "6780", "Lowest port to try and used for dyanmic ports", S },
-    { CYPHESIS, "dynamic_port_end", "<portnumber>", "6780", "Highest port to try and used for dyanmic ports", S },
-    { CYPHESIS, "unixport", "<filename>", DEFAULT_CLIENT_SOCKET, "Local listen socket for admin connections", S|C|M },
-    { CYPHESIS, "restricted", "true|false", "false", "Flag to control restricted mode", S },
-    { CYPHESIS, "usemetaserver", "true|false", "true", "Flag to control registration with the metaserver", S },
+    { CYPHESIS, "dynamic_port_start", "<portnumber>", "6800", "Lowest port to try and used for dyanmic ports", S },
+    { CYPHESIS, "dynamic_port_end", "<portnumber>", "6899", "Highest port to try and used for dyanmic ports", S },
     { CYPHESIS, "usedatabase", "true|false", "true", "Flag to control whether to use a database for persistent storage", S },
-    { CYPHESIS, "metaserver", "<hostname>", "metaserver.worldforge.org", "Hostname to use as the metaserver", S },
     { CYPHESIS, "daemon", "true|false", "false", "Flag to control running the server in daemon mode", S },
     { CYPHESIS, "nice", "<level>", "1", "Reduce the priority level of the server", S },
     { CYPHESIS, "useaiclient", "true|false", "false", "Flag to control whether AI is to be driven by a client", S },
@@ -110,14 +95,7 @@ static const usage_data usage[] = {
     { CYPHESIS, "dbname", "<name>", "\"cyphesis\"", "Name of the database to use", S|D },
     { CYPHESIS, "dbuser", "<dbusername>", "<username>", "Database user name for access", S|D },
     { CYPHESIS, "dbpasswd", "<dbusername>", "", "Database password for access", S|D },
-    { CLIENT, "package", "<package_name>", "define_world", "Python package which contains the world initialisation code", C },
-    { CLIENT, "function", "<function_name>", "default", "Python function to initialise the world", C },
-    { CLIENT, "serverhost", "<hostname>", "localhost", "Hostname of the server to connect to", S|C|M },
-    { CLIENT, "account", "<username>", "admin", "Account name to use to authenticate to the server", S|C },
-    { CLIENT, "password", "<password>", "", "Password to use to authenticate to the server", S|C },
-    { CLIENT, "useslave", "true|false", "false", "Flag to control connecting to an AI slave server, not master world server" , S|M },
     { SLAVE, "tcpport", "<portnumber>", "6768", "Network listen port for client connections to the AI slave server", M },
-    { SLAVE, "unixport", "<filename>", DEFAULT_SLAVE_SOCKET, "Local listen socket for admin connections to the AI slave server", M },
     { SLAVE, "server", "<hostname>", "localhost", "Master server to connect the slave to", M },
     { 0, 0, 0, 0 }
 };
@@ -181,37 +159,208 @@ int readConfigItem<std::string>(const std::string & section, const std::string &
     return -1;
 }
 
-typedef std::map<std::string, std::string> OptionHelp;
-typedef std::map<std::string, OptionHelp> UsageHelp;
+template int readConfigItem<bool>(const std::string & section, const std::string & key, bool & storage);
 
-static int check_config(varconf::Config & config,
-                        int usage_groups = USAGE_SERVER|
-                                           USAGE_CLIENT|
-                                           USAGE_CYCMD|
-                                           USAGE_DBASE)
+class Option {
+  protected:
+    std::string m_value;
+    std::string m_description;
+
+    Option(const std::string & val, const std::string & descr);
+  public:
+    virtual ~Option() = 0;
+
+    const std::string & value() { return m_value; }
+    const std::string & description() { return m_description; }
+
+    virtual void read(varconf::Variable var) = 0;
+
+    virtual const std::string repr() const = 0;
+
+    virtual size_t size() const = 0;
+
+    virtual void missing() { }
+
+    virtual void postProcess() { }
+};
+
+class DumbOption : public Option {
+  protected:
+    std::string m_default;
+  public:
+    DumbOption(const std::string & val, const std::string & descr,
+               const std::string & deflt);
+
+    virtual ~DumbOption() { }
+
+    virtual void read(varconf::Variable var) { }
+  
+    virtual const std::string repr() const;
+
+    virtual size_t size() const;
+};
+
+template<typename ValueT>
+class StaticOption : public Option {
+  protected:
+    ValueT & m_data;
+    const ValueT m_default;
+
+  public:
+    StaticOption(const std::string & val,
+                 const std::string & descr,
+                 ValueT & data) :
+        Option(val, descr), m_data(data), m_default(data) { }
+
+    virtual void read(varconf::Variable var);
+
+    virtual const std::string repr() const;
+
+    virtual size_t size() const;
+    
+};
+
+Option::Option(const std::string & val, const std::string & descr) :
+        m_value(val), m_description(descr)
 {
-    UsageHelp usage_help;
+}
 
+Option::~Option()
+{
+}
+
+DumbOption::DumbOption(const std::string & val,
+                       const std::string & descr,
+                       const std::string & deflt) :
+            Option(val, descr), m_default(deflt)
+{
+}
+
+const std::string DumbOption::repr() const
+{
+    return m_default;
+}
+
+size_t DumbOption::size() const
+{
+    return m_default.size();
+}
+
+template<>
+void StaticOption<std::string>::read(varconf::Variable var)
+{
+    m_data = var.as_string();
+}
+
+template<typename ValueT>
+void StaticOption<ValueT>::read(varconf::Variable var)
+{
+    m_data = var;
+}
+
+template<typename ValueT>
+const std::string StaticOption<ValueT>::repr() const
+{
+    return String::compose("%1", m_default);
+}
+
+template<typename ValueT>
+size_t StaticOption<ValueT>::size() const
+{
+    return String::compose("%1", m_default).size();
+}
+
+template class StaticOption<int>;
+
+class UnixSockOption : public StaticOption<std::string>
+{
+  protected:
+    const char * const m_format;
+  public:
+    UnixSockOption(const std::string & val,
+                   const std::string & descr,
+                   std::string & data,
+                   const char * format) :
+        StaticOption<std::string>(val, descr, data), m_format(format) { }
+
+    virtual void missing();
+
+    virtual void postProcess();
+};
+
+void UnixSockOption::missing()
+{
+    m_data = String::compose(m_format, instance);
+}
+
+void UnixSockOption::postProcess()
+{
+    if (m_data.find('/') != 0) {
+        m_data = String::compose("%1/tmp/%2",
+                                 var_directory,
+                                 m_data);
+    }
+}
+
+typedef std::map<std::string, Option *> OptionMap;
+typedef std::map<std::string, OptionMap> SectionMap;
+
+class Options {
+  protected:
+    SectionMap m_sectionMap;
+
+    static Options * m_instance;
+
+    explicit Options();
+  public:
+    static Options * instance() {
+        if (m_instance == 0) {
+            m_instance = new Options;
+        }
+        return m_instance;
+    }
+
+    const SectionMap & sectionMap() const {
+        return m_sectionMap;
+    }
+
+    int check_config(varconf::Config &, int usage_groups = USAGE_SERVER|
+                                                           USAGE_CLIENT|
+                                                           USAGE_CYCMD|
+                                                           USAGE_DBASE) const;
+
+    void addOption(const std::string & section,
+                   const std::string & setting,
+                   Option *);
+};
+
+Options * Options::m_instance = 0;
+
+Options::Options()
+{
     const usage_data * ud = &usage[0];
     for (; ud->section != 0; ++ud) {
-        if ((ud->flags & usage_groups) == 0) {
-            continue;
-        }
-        usage_help[ud->section].insert(std::make_pair(ud->option, ud->description));
+        m_sectionMap[ud->section].insert(std::make_pair(ud->option,
+              new DumbOption(ud->value, ud->description, ud->dflt)));
     }
-    
-    UsageHelp::const_iterator I = usage_help.begin();
-    UsageHelp::const_iterator Iend = usage_help.end();
+}
+
+int Options::check_config(varconf::Config & config,
+                          int usage_groups) const
+{
+    SectionMap::const_iterator I = m_sectionMap.begin();
+    SectionMap::const_iterator Iend = m_sectionMap.end();
     for (; I != Iend; ++I) {
         const std::string & section_name = I->first;
-        const OptionHelp & section_help = I->second;
+        const OptionMap & section_help = I->second;
         const varconf::sec_map & section = config.getSection(section_name);
 
         varconf::sec_map::const_iterator J = section.begin();
         varconf::sec_map::const_iterator Jend = section.end();
         for (; J != Jend; ++J) {
             const std::string & option_name = J->first;
-            if (section_help.find(J->first) == section_help.end()) {
+            if (section_help.find(J->first) == section_help.end() &&
+                J->second->scope() == varconf::INSTANCE) {
                 log(WARNING, String::compose("Invalid option -- %1:%2",
                                              section_name, option_name));
             }
@@ -220,6 +369,56 @@ static int check_config(varconf::Config & config,
     return 0;
 }
 
+void Options::addOption(const std::string & section,
+                        const std::string & setting,
+                        Option * option)
+{
+    OptionMap & config_section = m_sectionMap[section];
+    if (config_section.find(setting) != config_section.end()) {
+        log(ERROR, String::compose("Config option %1:%2 already defined",
+                                   section, setting));
+        return;
+    }
+    m_sectionMap[section].insert(std::make_pair(setting, option));
+}
+
+int_config_register::int_config_register(int & var,
+                                         const char * section,
+                                         const char * setting,
+                                         const char * help)
+{
+    Options::instance()->addOption(section, setting,
+                                   new StaticOption<int>("<foo>", help, var));
+}
+
+bool_config_register::bool_config_register(bool & var,
+                                           const char * section,
+                                           const char * setting,
+                                           const char * help)
+{
+    Options::instance()->addOption(section, setting,
+                                   new StaticOption<bool>("<foo>", help, var));
+}
+
+string_config_register::string_config_register(std::string & var,
+                                               const char * section,
+                                               const char * setting,
+                                               const char * help)
+{
+    Options::instance()->addOption(section, setting,
+                                   new StaticOption<std::string>("<foo>", help, var));
+}
+
+unixsock_config_register::unixsock_config_register(std::string & var,
+                                                   const char * section,
+                                                   const char * setting,
+                                                   const char * help,
+                                                   const char * format)
+{
+    Options::instance()->addOption(section, setting,
+                                   new UnixSockOption("<foo>", help, var, format));
+}
+
 void readInstanceConfiguration(const std::string & section);
 
 int loadConfig(int argc, char ** argv, int usage)
@@ -235,7 +434,7 @@ int loadConfig(int argc, char ** argv, int usage)
     // inappropriate options.
     varconf::Config test_cmdline;
     test_cmdline.getCmdline(argc, argv);
-    check_config(test_cmdline, usage);
+    Options::instance()->check_config(test_cmdline, usage);
 
     // See if the user has set the install directory on the command line
     bool home_dir_config = false;
@@ -281,7 +480,7 @@ int loadConfig(int argc, char ** argv, int usage)
 
     int optind = global_conf->getCmdline(argc, argv);
 
-    check_config(*global_conf);
+    Options::instance()->check_config(*global_conf);
 
     assert(optind > 0);
 
@@ -300,6 +499,25 @@ int loadConfig(int argc, char ** argv, int usage)
     readConfigItem("cyphesis", "dynamic_port_start", dynamic_port_start);
     readConfigItem("cyphesis", "dynamic_port_end", dynamic_port_end);
 
+    Options * options = Options::instance();
+
+    SectionMap::const_iterator I = options->sectionMap().begin();
+    SectionMap::const_iterator Iend = options->sectionMap().end();
+    OptionMap::const_iterator J;
+    OptionMap::const_iterator Jend;
+    for (; I != Iend; ++I) {
+        J = I->second.begin();
+        Jend = I->second.end();
+        for (; J != Jend; ++J) {
+            if (global_conf->findItem(I->first, J->first)) {
+                J->second->read(global_conf->getItem(I->first, J->first));
+            } else {
+                J->second->missing();
+            }
+            J->second->postProcess();
+        }
+    }
+
     readInstanceConfiguration(instance);
 
     return optind;
@@ -335,18 +553,6 @@ void readInstanceConfiguration(const std::string & section)
         }
     }
 
-    if (readConfigItem(section, "unixport", client_socket_name) != 0) {
-        client_socket_name = String::compose("cyphesis_%1.sock", section);
-    }
-
-    readConfigItem("slave", "tcpport", slave_port_num);
-
-    readConfigItem("slave", "unixport", slave_socket_name);
-
-    readConfigItem("game", "player_vs_player", pvp_flag);
-
-    readConfigItem("game", "player_vs_player_offline", pvp_offl_flag);
-
     // Load up the ruleset.
     if (readConfigItem(section, "ruleset", ruleset)) {
         if (section == DEFAULT_INSTANCE) {
@@ -403,9 +609,18 @@ void showUsage(const char * prgname, int usage_flags, const char * extras)
     
     size_t column_width = 0;
 
-    const usage_data * ud = &usage[0];
-    for (; ud->section != 0; ++ud) {
-        column_width = std::max(column_width, strlen(ud->section) + strlen(ud->option) + strlen(ud->value) + 2);
+    Options * options = Options::instance();
+
+    SectionMap::const_iterator I = options->sectionMap().begin();
+    SectionMap::const_iterator Iend = options->sectionMap().end();
+    OptionMap::const_iterator J;
+    OptionMap::const_iterator Jend;
+    for (; I != Iend; ++I) {
+        J = I->second.begin();
+        Jend = I->second.end();
+        for (; J != Jend; ++J) {
+            column_width = std::max(column_width, I->first.size() + J->first.size() + J->second->value().size() + 2);
+        }
     }
 
     std::cout << "  --help, -h        Display usage information and exit"
@@ -414,29 +629,31 @@ void showUsage(const char * prgname, int usage_flags, const char * extras)
     std::cout << "  --version, -v     Display the version information and exit"
               << std::endl << std::endl;
 
-    ud = &usage[0];
-    for (; ud->section != 0; ++ud) {
-        if ((ud->flags & usage_flags) == 0) {
-            continue;
-        }
-        if (strlen(ud->section) != 0) {
-            std::cout << "  --" << ud->section << ":" << ud->option;
-        } else {
-            std::cout << "  --" << ud->option;
-        }
-        if (ud->value != 0 && strlen(ud->value) != 0) {
-            std::cout << "=" << ud->value;
-        }
-        if (ud->dflt != 0 && strlen(ud->dflt) != 0) {
-            size_t len = strlen(ud->section) + 1 + strlen(ud->option);
-            if (ud->value != 0 && strlen(ud->value) != 0) {
-                len += (strlen(ud->value) + 1);
+    I = options->sectionMap().begin();
+    for (; I != Iend; ++I) {
+        J = I->second.begin();
+        Jend = I->second.end();
+        for (; J != Jend; ++J) {
+            if (I->first.size() != 0) {
+                std::cout << "  --" << I->first << ":" << J->first;
+            } else {
+                std::cout << "  --" << J->first;
             }
-            std::cout << std::string(column_width - len + 2, ' ')
-                      << "= " << ud->dflt;
+            Option * opt = J->second;
+            if (opt->value().size() != 0) {
+                std::cout << "=" << opt->value();
+            }
+            if (opt->size() != 0) {
+                size_t len = I->first.size() + 1 + J->first.size();
+                if (opt->value().size() != 0) {
+                    len += (opt->value().size() + 1);
+                }
+                std::cout << std::string(column_width - len + 2, ' ')
+                          << "= " << opt->repr();
+            }
+            std::cout << std::endl;
+            std::cout << "      " << opt->description() << std::endl;
         }
-        std::cout << std::endl;
-        std::cout << "      " << ud->description << std::endl;
     }
     std::cout << std::flush;
 }
