@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: BaseMind.cpp,v 1.113 2008-01-26 17:43:21 alriddoch Exp $
+// $Id$
 
 #include "BaseMind.h"
 
@@ -24,11 +24,7 @@
 #include "common/log.h"
 #include "common/debug.h"
 #include "common/op_switch.h"
-#include "common/inheritance.h"
-
-#include "common/Attack.h"
-#include "common/Setup.h"
-#include "common/Tick.h"
+#include "common/Inheritance.h"
 
 #include <Atlas/Objects/SmartPtr.h>
 #include <Atlas/Objects/Operation.h>
@@ -50,7 +46,6 @@ static const bool debug_flag = false;
 /// @param intId Integer identifier
 /// @param body_name The name attribute of the body this mind controls
 BaseMind::BaseMind(const std::string & id, long intId) :
-          Identified(id, intId),
           MemEntity(id, intId), m_map(m_script), m_isAwake(true)
 {
     setVisible(true);
@@ -297,9 +292,9 @@ void BaseMind::callSightOperation(const Operation & op,
     m_map.getAdd(op->getFrom());
     OpNo op_no = op->getClassNo();
     if (debug_flag && (op_no == OP_INVALID)) {
-        std::cout << getId() << " could not deliver sight of "
-                  << op->getParents().front()
-                  << std::endl << std::flush;
+        debug(std::cout << getId() << " could not deliver sight of "
+                        << op->getParents().front()
+                        << std::endl << std::flush;);
     }
     SUB_OP_SWITCH(op, op_no, res, sight)
 }
@@ -312,9 +307,9 @@ void BaseMind::callSoundOperation(const Operation & op,
     m_map.getAdd(op->getFrom());
     OpNo op_no = op->getClassNo();
     if (debug_flag && (op_no == OP_INVALID)) {
-        std::cout << getId() << " could not deliver sound of "
-                  << op->getParents().front()
-                  << std::endl << std::flush;
+        debug(std::cout << getId() << " could not deliver sound of "
+                        << op->getParents().front()
+                        << std::endl << std::flush;);
     }
 
 #if 0
