@@ -15,19 +15,17 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Character.cpp,v 1.323 2008-05-28 19:42:36 alriddoch Exp $
+// $Id$
 
 #include "Character.h"
 
 #include "Pedestrian.h"
-#include "MindFactory.h"
 #include "BaseMind.h"
-#include "Script.h"
 #include "World.h"
 #include "Task.h"
-#include "StatisticsProperty.h"
 #include "EntityProperty.h"
 #include "OutfitProperty.h"
+#include "StatusProperty.h"
 
 #include "common/op_switch.h"
 #include "common/const.h"
@@ -42,7 +40,6 @@
 #include "common/Actuate.h"
 #include "common/Attack.h"
 #include "common/Eat.h"
-#include "common/Nourish.h"
 #include "common/Setup.h"
 #include "common/Tick.h"
 #include "common/Unseen.h"
@@ -63,13 +60,9 @@ using Atlas::Objects::Operation::Set;
 using Atlas::Objects::Operation::Sight;
 using Atlas::Objects::Operation::Sound;
 using Atlas::Objects::Operation::Tick;
-using Atlas::Objects::Operation::Look;
 using Atlas::Objects::Operation::Move;
-using Atlas::Objects::Operation::Setup;
 using Atlas::Objects::Operation::Action;
 using Atlas::Objects::Operation::Unseen;
-using Atlas::Objects::Operation::Nourish;
-using Atlas::Objects::Operation::Appearance;
 using Atlas::Objects::Operation::Update;
 using Atlas::Objects::Operation::Wield;
 using Atlas::Objects::Entity::Anonymous;
@@ -99,8 +92,16 @@ const double Character::energyLaidDown = 0.1;
 // Ammount of weight gained as a result. High for Acorn.
 const double Character::weightGain = 0.5;
 
-static const std::string RIGHT_HAND_WIELD = "right_hand_wield";
+static const std::string FOOD = "food";
+static const std::string MASS = "mass";
+static const std::string MAXMASS = "maxmass";
 static const std::string OUTFIT = "outfit";
+static const std::string RIGHT_HAND_WIELD = "right_hand_wield";
+static const std::string SERIALNO = "serialno";
+static const std::string STAMINA = "stamina";
+static const std::string STATISTICS = "statistics";
+static const std::string STATUS = "status";
+static const std::string TASKS = "tasks";
 
 /// \brief Calculate how the Characters metabolism has affected it in the
 /// last tick
@@ -115,90 +116,79 @@ static const std::string OUTFIT = "outfit";
 /// @param ammount Time scale factor, currently not used.
 void Character::metabolise(OpVector & res, double ammount)
 {
-    bool stamina_changed = false,
-         mass_changed = false;
-
     // Currently handles energy
     // We should probably call this whenever the entity performs a movement.
 
-    PropertyBase * status_prop = getProperty("status");
+    StatusProperty * status_prop = modPropertyClass<StatusProperty>(STATUS);
     if (status_prop == 0) {
-        status_prop = PropertyManager::instance()->addProperty(this, "status");
-        if (status_prop == 0) {
-            log(ERROR, "Unable to get a STATUS property.");
-            return;
-        }
-        m_properties["status"] = status_prop;
+        // FIXME Probably don't do enough here to set up the property.
+        status_prop = new StatusProperty;
+        assert(status_prop != 0);
+        m_properties[STATUS] = status_prop;
         status_prop->set(1.f);
     }
-    Element value;
-    status_prop->get(value);
-    assert(value.isFloat());
-    float status = value.asFloat();
+    double & status = status_prop->data();
+    status_prop->setFlags(flag_unsent);
 
-    Anonymous update_arg;
-    update_arg->setId(getId());
-
-    PropertyBase * food_prop = getProperty("food");
+    Property<double> * food_prop = modPropertyType<double>(FOOD);
     // DIGEST
-    if (food_prop != 0 && food_prop->get(value) && value.isFloat()) {
-        float food = value.Float();
+    if (food_prop != 0) {
+        double & food = food_prop->data();
         if (food >= foodConsumption && status < 2) {
             // It is important that the metabolise bit is done next, as this
             // handles the status change
             status += foodConsumption;
             food -= foodConsumption;
-            food_prop->set(food);
 
-            update_arg->setAttr("food", food);
+            food_prop->setFlags(flag_unsent);
         }
     }
 
-    PropertyBase * mass_prop = getProperty("mass");
-    float mass = 0.f;
-    if (mass_prop != 0 && mass_prop->get(value) && value.isFloat()) {
-        mass = value.Float();
-    }
+    Property<double> * mass_prop = modPropertyType<double>(MASS);
     // If status is very high, we gain weight
-    if (status > (1.5 + energyLaidDown) && mass < m_maxMass) {
+    if (status > (1.5 + energyLaidDown)) {
         status -= energyLaidDown;
-        mass += weightGain;
-        mass_changed = true;
+        if (mass_prop != 0) {
+            double & mass = mass_prop->data();
+            mass += weightGain;
+            mass_prop->setFlags(flag_unsent);
+            Element maxmass_attr;
+            if (getAttrType(MAXMASS, maxmass_attr, Element::TYPE_FLOAT)) {
+                mass = std::min(mass, maxmass_attr.Float());
+            }
+        }
     } else {
         // If status is relatively is not very high, then energy is burned
         double energy_used = energyConsumption * ammount;
-        double weight_used = weightConsumption * mass * ammount;
-        if (status <= 0.5 && mass > weight_used) {
-            // Drain away a little energy and lose some weight
-            // This ensures there is a long term penalty to allowing something
-            // to starve
-            status -= (energy_used / 2);
-            mass -= weight_used;
-            mass_changed = true;
-        } else {
-            // Just drain away a little energy
-            status -= energy_used;
+        status -= energy_used;
+        if (mass_prop != 0) {
+            double & mass = mass_prop->data();
+            double weight_used = weightConsumption * mass * ammount;
+            if (status <= 0.5 && mass > weight_used) {
+                // Drain away a little less energy and lose some weight
+                // This ensures there is a long term penalty to allowing
+                // something to starve
+                status += (energy_used / 2);
+                mass -= weight_used;
+                mass_prop->setFlags(flag_unsent);
+            }
         }
     }
-    if (m_stamina < 1. && m_task == 0 && !m_movement.updateNeeded(m_location)) {
-        m_stamina = 1.;
-        stamina_changed = true;
-    }
+    // FIXME Stamina property?
+    if (m_task == 0 && !m_movement.updateNeeded(m_location)) {
 
-    status_prop->set(status);
-    update_arg->setAttr("status", status);
-
-    if (mass_changed && mass_prop != 0) {
-        mass_prop->set(mass);
-        update_arg->setAttr("mass", mass);
-    }
-    if (stamina_changed) {
-        update_arg->setAttr("stamina", m_stamina);
+        Property<double> * stamina_prop = modPropertyType<double>(STAMINA);
+        if (stamina_prop != 0) {
+            double & stamina = stamina_prop->data();
+            if (stamina < 1.f) {
+                stamina = 1.f;
+                stamina_prop->setFlags(flag_unsent);
+            }
+        }
     }
 
     Update update;
     update->setTo(getId());
-    update->setArgs1(update_arg);
 
     res.push_back(update);
 }
@@ -257,21 +247,10 @@ LocatedEntity * Character::findInInventory(const std::string & id)
 /// @param id String identifier
 /// @param intId Integer identifier
 Character::Character(const std::string & id, long intId) :
-           Identified(id, intId),
            Character_parent(id, intId),
-               m_statistics(*this),
                m_movement(*new Pedestrian(*this)),
-               m_task(0), m_isAlive(true),
-               m_stamina(1.),
-               m_maxMass(100),
-               m_mind(0), m_externalMind(0)
+               m_task(0), m_mind(0), m_externalMind(0)
 {
-    m_location.setBBox(BBox(WFMath::Point<3>(-0.25, -0.25, 0),
-                            WFMath::Point<3>(0.25, 0.25, 2)));
-
-    m_properties["stamina"] = new Property<double>(m_stamina, 0);
-    m_properties["statistics"] = new StatisticsProperty(m_statistics, 0);
-    m_properties[RIGHT_HAND_WIELD] = new EntityProperty;
 }
 
 Character::~Character()
@@ -335,13 +314,13 @@ void Character::clearTask()
     m_task = 0;
 
     Anonymous set_arg;
-    set_arg->setAttr("tasks", ListType());
+    set_arg->setAttr(TASKS, ListType());
     set_arg->setId(getId());
 
     Set set;
     set->setArgs1(set_arg);
     set->setTo(getId());
-    
+
     sendWorld(set);
 }
 
@@ -352,42 +331,6 @@ void Character::ImaginaryOperation(const Operation & op, OpVector & res)
     res.push_back(s);
 }
 
-void Character::SetupOperation(const Operation & op, OpVector & res)
-{
-    debug( std::cout << "CHaracter::SetupOperation()" << std::endl
-                     << std::flush;);
-
-    if (!op->getArgs().empty()) {
-        debug( std::cout << __func__ << " Setup op is for subsystem" << std::endl << std::flush;);
-        return;
-    }
-
-    if (0 == m_externalMind) {
-        // This ensures that newly created player characters don't get
-        // bogged down with an NPC mind. In the short term this
-        // takes away PC programmability.
-        // FIXME Characters restored from the database will still get
-        // AI minds, so  we need to handle them somehow differently.
-        // Perhaps the Restore op (different from Setup op) is needed?
-
-        m_mind = MindFactory::instance()->newMind(getId(), getIntId(), m_type);
-
-        Operation s(op.copy());
-        Anonymous setup_arg;
-        setup_arg->setName("mind");
-        s->setArgs1(setup_arg);
-        res.push_back(s);
-
-        Look l;
-        l->setTo(getId());
-        res.push_back(l);
-    }
-
-    Tick tick;
-    tick->setTo(getId());
-    res.push_back(tick);
-}
-
 void Character::TickOperation(const Operation & op, OpVector & res)
 {
     debug(std::cout << "================================" << std::endl
@@ -398,7 +341,7 @@ void Character::TickOperation(const Operation & op, OpVector & res)
         if (arg->getName() == "move") {
             // Deal with movement.
             Element serialno;
-            if (arg->copyAttr("serialno", serialno) == 0 && (serialno.isInt())) {
+            if (arg->copyAttr(SERIALNO, serialno) == 0 && (serialno.isInt())) {
                 if (serialno.asInt() < m_movement.serialno()) {
                     debug(std::cout << "Old tick" << std::endl << std::flush;);
                     return;
@@ -413,7 +356,7 @@ void Character::TickOperation(const Operation & op, OpVector & res)
             res.push_back(m_movement.generateMove(return_location));
             Anonymous tick_arg;
             tick_arg->setName("move");
-            tick_arg->setAttr("serialno", m_movement.serialno());
+            tick_arg->setAttr(SERIALNO, m_movement.serialno());
             Tick tickOp;
             tickOp->setTo(getId());
             tickOp->setFutureSeconds(m_movement.getTickAddition(return_location.pos(), return_location.velocity()));
@@ -425,7 +368,7 @@ void Character::TickOperation(const Operation & op, OpVector & res)
                 return;
             }
             Element serialno;
-            if (arg->copyAttr("serialno", serialno) == 0 && (serialno.isInt())) {
+            if (arg->copyAttr(SERIALNO, serialno) == 0 && (serialno.isInt())) {
                 if (serialno.asInt() != m_task->serialno()) {
                     debug(std::cout << "Old tick" << std::endl << std::flush;);
                     return;
@@ -475,29 +418,19 @@ void Character::NourishOperation(const Operation & op, OpVector & res)
     }
     const Root & arg = op->getArgs().front();
     Element mass_attr;
-    if (arg->copyAttr("mass", mass_attr) != 0 || !mass_attr.isNum()) {
+    if (arg->copyAttr(MASS, mass_attr) != 0 || !mass_attr.isNum()) {
         return;
     }
 
-    PropertyBase * food_property = getProperty("food");
-    if (food_property == 0) {
-        food_property = PropertyManager::instance()->addProperty(this, "food");
-        if (food_property == 0) {
-            log(ERROR, "Unable to set a FOOD property.");
-            return;
-        }
-        m_properties["food"] = food_property;
-    }
-    Element value;
-    food_property->get(value);
-    assert(value.isFloat());
-    float food = value.Float();
-    food = food + mass_attr.asNum();
-    food_property->set(food);
+    Property<double> * food_prop = requirePropertyClass<Property<double> >(FOOD, 0.f);
+    double & food = food_prop->data();
+    food += mass_attr.asNum();
+    food_prop->setFlags(flag_unsent);
 
+    // FIXME This will become a Update once private properties are sorted
     Anonymous food_ent;
     food_ent->setId(getId());
-    food_ent->setAttr("food", food);
+    food_ent->setAttr(FOOD, food);
 
     Set s;
     s->setArgs1(food_ent);
@@ -512,12 +445,13 @@ void Character::NourishOperation(const Operation & op, OpVector & res)
 void Character::WieldOperation(const Operation & op, OpVector & res)
 {
     if (op->getArgs().empty()) {
-        EntityProperty * rhw = getSpecificProperty<EntityProperty>(RIGHT_HAND_WIELD);
+        EntityProperty * rhw = modPropertyClass<EntityProperty>(RIGHT_HAND_WIELD);
         if (rhw == 0) {
             return;
         }
 
         rhw->data() = EntityRef(0);
+        rhw->setFlags(flag_unsent);
         // FIXME Remove the property?
 
         // FIXME Make sure we stop wielding if the container changes,
@@ -528,10 +462,6 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
 
         Update update;
         update->setTo(getId());
-        Anonymous update_arg;
-        update_arg->setId(getId());
-        update_arg->setAttr(RIGHT_HAND_WIELD, "");
-        update->setArgs1(update_arg);
         res.push_back(update);
 
         return;
@@ -549,25 +479,26 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
     }
 
     if (m_contains == 0 || m_contains->find(item) == m_contains->end()) {
-        error(op, "Wield arg is not in inventory", res, getId());
+        error(op, String::compose("Wield arg %1(%2) is not in inventory "
+                                  "of %3(%4)", 
+                                  item->getType()->name(), id,
+                                  getType()->name(), getId()), res, getId());
         return;
     }
 
-    Anonymous update_arg;
-    update_arg->setId(getId());
-
     Element worn_attr;
     if (item->getAttr("worn", worn_attr)) {
         debug(std::cout << "Got wield for a garment" << std::endl << std::flush;);
-        
+
         if (worn_attr.isString()) {
-            OutfitProperty * outfit = requireSpecificProperty<OutfitProperty>(OUTFIT);
+            OutfitProperty * outfit = requirePropertyClass<OutfitProperty>(OUTFIT);
             outfit->wear(this, worn_attr.String(), item);
             outfit->cleanUp();
 
-            update_arg->setAttr(OUTFIT, MapType());
+            outfit->setFlags(flag_unsent);
         } else {
             log(WARNING, "Got clothing with non-string worn attribute.");
+            return;
         }
         // FIXME Implement adding stuff to the outfit propert, as efficiently
         // as possible
@@ -577,7 +508,7 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
     } else {
         debug(std::cout << "Got wield for a tool" << std::endl << std::flush;);
 
-        EntityProperty * rhw = requireSpecificProperty<EntityProperty>(RIGHT_HAND_WIELD);
+        EntityProperty * rhw = requirePropertyClass<EntityProperty>(RIGHT_HAND_WIELD);
         // FIXME Make sure we don't stay linked to the previous wielded
         // tool.
         // if (m_rightHandWieldConnection.connected()) {
@@ -586,8 +517,8 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
 
         // The value is ignored by the update handler, but should be the
         // right type.
-        update_arg->setAttr(RIGHT_HAND_WIELD, item->getId());
         rhw->data() = EntityRef(item);
+        rhw->setFlags(flag_unsent);
 
         item->containered.connect(sigc::mem_fun(this, &Character::wieldDropped));
 
@@ -596,7 +527,6 @@ void Character::WieldOperation(const Operation & op, OpVector & res)
 
     Update update;
     update->setTo(getId());
-    update->setArgs1(update_arg);
     res.push_back(update);
 }
 
@@ -867,7 +797,7 @@ void Character::mindUseOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    EntityProperty * rhw = getSpecificProperty<EntityProperty>(RIGHT_HAND_WIELD);
+    EntityProperty * rhw = modPropertyClass<EntityProperty>(RIGHT_HAND_WIELD);
     if (rhw == 0) {
         error(op, "Character::mindUseOp No tool wielded.", res, getId());
         return;
@@ -1108,9 +1038,12 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
         log(ERROR, "mindMoveOperation: Arg has no ID");
         return;
     }
-    if (getStamina() <= 0.f) {
-        // Character is immobilised.
-        return;
+    Element stamina_attr;
+    if (getAttrType(STAMINA, stamina_attr, Element::TYPE_FLOAT)) {
+        if (stamina_attr.Float() <= 0.f) {
+            // Character is immobilised.
+            return;
+        }
     }
     const std::string & other_id = arg->getId();
     if (other_id != getId()) {
@@ -1128,8 +1061,9 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
             return;
         }
         Element mass;
-        if (!other->getAttr("mass", mass) || !mass.isFloat() ||
-            mass.Float() > m_statistics.get("strength")) {
+        if (!other->getAttr(MASS, mass) || !mass.isFloat()) {
+            // FIXME Check against strength
+            // || mass.Float() > m_statistics.get("strength"));
             debug( std::cout << "We can't move this. Just too heavy" << std::endl << std::flush;);
             return;
         }
@@ -1273,7 +1207,7 @@ void Character::mindMoveOperation(const Operation & op, OpVector & res)
 
         Tick tickOp;
         Anonymous tick_arg;
-        tick_arg->setAttr("serialno", m_movement.serialno());
+        tick_arg->setAttr(SERIALNO, m_movement.serialno());
         tick_arg->setName("move");
         tickOp->setArgs1(tick_arg);
         tickOp->setTo(getId());
@@ -1315,7 +1249,7 @@ void Character::mindSetOperation(const Operation & op, OpVector & res)
 /// @param res The filtered result is returned here.
 void Character::mindCombineOperation(const Operation & op, OpVector & res)
 {
-    std::cout << "mindCombineOperation" << std::endl << std::flush;
+    debug(std::cout << "mindCombineOperation" << std::endl << std::flush;);
     const std::vector<Root> & args = op->getArgs();
     if (args.empty()) {
         log(ERROR, "mindCombineOperation: combine op has no argument");
@@ -1419,7 +1353,7 @@ void Character::mindLookOperation(const Operation & op, OpVector & res)
 {
     debug(std::cout << "Got look up from mind from [" << op->getFrom()
                << "] to [" << op->getTo() << "]" << std::endl << std::flush;);
-    m_perceptive = true;
+    m_flags |= entity_perceptive;
     const std::vector<Root> & args = op->getArgs();
     if (args.empty()) {
         op->setTo(BaseWorld::instance().m_gameWorld.getId());
@@ -1714,10 +1648,6 @@ void Character::operation(const Operation & op, OpVector & res)
 {
     debug( std::cout << "Character::operation(" << op->getParents().front() << ")" << std::endl << std::flush;);
     Entity::operation(op, res);
-    // set refno on result?
-    if (!m_isAlive) {
-        return;
-    }
     if (world2mind(op)) {
         debug( std::cout << "Character::operation(" << op->getParents().front() << ") passed to mind" << std::endl << std::flush;);
         OpVector mres;
