@@ -15,15 +15,13 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Character.h,v 1.105 2008-05-28 19:42:36 alriddoch Exp $
+// $Id$
 
 #ifndef RULESETS_CHARACTER_H
 #define RULESETS_CHARACTER_H
 
 #include "Thing.h"
 
-#include "Statistics.h"
-
 #include "modules/EntityRef.h"
 
 #include <sigc++/connection.h>
@@ -48,20 +46,10 @@ typedef Thing Character_parent;
 /// \ingroup EntityClasses
 class Character : public Character_parent {
   protected:
-    /// \brief Mathematical model that calculates characters stats and abilities
-    Statistics m_statistics;
     /// \brief Handler for simulating movement under direction from the mind
     Movement & m_movement;
     /// \brief Handler for a medium term task being undertaken
     Task * m_task;
-    /// \brief Flag indicating if this entity is alive
-    bool m_isAlive;
-
-    // Properties
-    /// \brief Level of stamina character has left
-    double m_stamina;
-    /// \brief Maximum mass of this type of creature
-    double m_maxMass;
 
     /// \brief Energy loss by metabolism per tick
     static const double energyConsumption;
@@ -84,19 +72,14 @@ class Character : public Character_parent {
     /// \brief Internal AI mind controlling this character
     BaseMind * m_mind;
     /// \brief External network connected agent controlling this character
-    IdentifiedRouter * m_externalMind;
+    Router * m_externalMind;
 
     explicit Character(const std::string & id, long intId);
     virtual ~Character();
 
-    /// \brief Accessor for mathematical stats model
-    Statistics & statistics() { return m_statistics; }
     /// \brief Accessor for medium term task
     Task * task() { return m_task; }
 
-    /// \brief Accessor for raw stamina property
-    const double getStamina() const { return m_stamina; }
-
     void setTask(Task *);
     void updateTask();
     void clearTask();
@@ -105,7 +88,6 @@ class Character : public Character_parent {
     virtual void externalOperation(const Operation & op);
 
     virtual void ImaginaryOperation(const Operation & op, OpVector &);
-    virtual void SetupOperation(const Operation & op, OpVector &);
     virtual void TickOperation(const Operation & op, OpVector &);
     virtual void TalkOperation(const Operation & op, OpVector &);
     virtual void NourishOperation(const Operation & op, OpVector &);
