@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Entity.cpp,v 1.154 2008-03-26 01:34:16 alriddoch Exp $
+// $Id$
 
 #include "Entity.h"
 
@@ -57,15 +57,20 @@ using Atlas::Objects::smart_dynamic_cast;
 
 static const bool debug_flag = false;
 
+/// \brief Flags used to control entities
+///
+/// These flags are used to indicate various aspects of entities.
+/// \defgroup EntityFlags In World Entity Flags
+
+/// \brief Classes that model in world entities
+///
+/// These classes are used to model all in world entities or objects.
+/// \defgroup EntityClasses In World Entity Classes
+
 /// \brief Entity constructor
 Entity::Entity(const std::string & id, long intId) :
-        Identified(id, intId),
-        LocatedEntity(id, intId), m_destroyed(false), m_motion(0),
-        m_perceptive(false), m_update_flags(0)
+        LocatedEntity(id, intId), m_motion(0), m_flags(0)
 {
-    SignalProperty<BBox> * sp = new SignalProperty<BBox>(m_location.m_bBox, a_bbox);
-    sp->modified.connect(sigc::mem_fun(&m_location, &Location::modifyBBox));
-    m_properties["bbox"] = sp;
 }
 
 Entity::~Entity()
@@ -74,23 +79,72 @@ Entity::~Entity()
 
 void Entity::setAttr(const std::string & name, const Element & attr)
 {
+    PropertyBase * prop;
+    // If it is an existing property, just update the value.
     PropertyDict::const_iterator I = m_properties.find(name);
     if (I != m_properties.end()) {
-        I->second->set(attr);
-        m_update_flags |= I->second->flags();
+        prop = I->second;
+        prop->set(attr);
+        // Allow the change to take effect.
+        prop->apply(this);
+        // Mark it as unclean and the Entity as unclean
+        prop->resetFlags(per_clean);
+        resetFlags(entity_clean);
         return;
     }
-    PropertyBase * prop = PropertyManager::instance()->addProperty(this, name);
-    if (prop == 0) {
-        prop = new SoftProperty(attr);
-    } else {
-        prop->set(attr);
-    }
+    prop = PropertyManager::instance()->addProperty(name, attr.getType());
+    assert(prop != 0);
+    prop->set(attr);
     m_properties[name] = prop;
-    m_update_flags |= prop->flags();
+    // If this is an entirely new property, not just a modifcation of
+    // one in defaults, then we need to install it to this Entity.
+    if (m_type == 0 || m_type->defaults().find(name) == m_type->defaults().end()) {
+        prop->install(this);
+    }
+    // Allow the value to take effect.
+    prop->apply(this);
+    resetFlags(entity_clean);
     return;
 }
 
+const PropertyBase * Entity::getProperty(const std::string & name) const
+{
+    PropertyDict::const_iterator I = m_properties.find(name);
+    if (I != m_properties.end()) {
+        return I->second;
+    }
+    if (m_type != 0) {
+        I = m_type->defaults().find(name);
+        if (I != m_type->defaults().end()) {
+            return I->second;
+        }
+    }
+    return 0;
+}
+
+PropertyBase * Entity::modProperty(const std::string & name)
+{
+    PropertyDict::const_iterator I = m_properties.find(name);
+    if (I != m_properties.end()) {
+        return I->second;
+    }
+    if (m_type != 0) {
+        I = m_type->defaults().find(name);
+        if (I != m_type->defaults().end()) {
+            // We have a default for this property. Create a new instance
+            // property with the same value.
+            Element val;
+            I->second->get(val);
+            PropertyBase * new_prop = PropertyManager::instance()->addProperty(name, val.getType());
+            new_prop->set(val);
+            m_properties[name] = new_prop;
+            new_prop->apply(this);
+            return new_prop;
+        }
+    }
+    return 0;
+}
+
 /// \brief Set the property object for a given attribute
 ///
 /// @param name name of the attribute for which the property is given
@@ -106,11 +160,23 @@ void Entity::setProperty(const std::string & name, PropertyBase * prop)
 void Entity::addToMessage(MapType & omap) const
 {
     // We need to have a list of keys to pull from attributes.
-    PropertyDict::const_iterator J = m_properties.begin();
-    PropertyDict::const_iterator Jend = m_properties.end();
+    PropertyDict::const_iterator J;
+    PropertyDict::const_iterator Jend;
+
+    if (m_type != 0) {
+        J = m_type->defaults().begin();
+        Jend = m_type->defaults().end();
+        for (; J != Jend; ++J) {
+            J->second->add(J->first, omap);
+        }
+    }
+
+    J = m_properties.begin();
+    Jend = m_properties.end();
     for (; J != Jend; ++J) {
         J->second->add(J->first, omap);
     }
+
     omap["stamp"] = (double)m_seq;
     omap["parents"] = ListType(1, m_type);
     m_location.addToMessage(omap);
@@ -123,11 +189,23 @@ void Entity::addToMessage(MapType & omap) const
 void Entity::addToEntity(const RootEntity & ent) const
 {
     // We need to have a list of keys to pull from attributes.
-    PropertyDict::const_iterator J = m_properties.begin();
-    PropertyDict::const_iterator Jend = m_properties.end();
+    PropertyDict::const_iterator J;
+    PropertyDict::const_iterator Jend;
+
+    if (m_type != 0) {
+        J = m_type->defaults().begin();
+        Jend = m_type->defaults().end();
+        for (; J != Jend; ++J) {
+            J->second->add(J->first, ent);
+        }
+    }
+
+    J = m_properties.begin();
+    Jend = m_properties.end();
     for (; J != Jend; ++J) {
         J->second->add(J->first, ent);
     }
+
     ent->setStamp(m_seq);
     ent->setParents(std::list<std::string>(1, m_type->name()));
     m_location.addToEntity(ent);
@@ -183,10 +261,10 @@ void Entity::destroy()
 
     if (loc_contains.empty()) {
         Entity * loc = dynamic_cast<Entity *>(m_location.m_loc);
-        loc->m_update_flags |= a_cont;
-        loc->updated.emit();
+        // FIXME Do we need to call onUpdated() on the parent entity?
+        loc->onUpdated();
     }
-    m_destroyed = true;
+    m_flags |= entity_destroyed;
     destroyed.emit();
 }
 
@@ -246,10 +324,6 @@ void Entity::SetOperation(const Operation &, OpVector &)
 {
 }
 
-void Entity::SetupOperation(const Operation &, OpVector &)
-{
-}
-
 void Entity::SightOperation(const Operation &, OpVector &)
 {
 }
@@ -328,3 +402,8 @@ void Entity::onContainered()
 
     containered.clear();
 }
+
+void Entity::onUpdated()
+{
+    updated.emit();
+}
