@@ -15,26 +15,48 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Entity.h,v 1.102 2008-03-26 01:34:16 alriddoch Exp $
+// $Id$
 
 #ifndef RULESETS_ENTITY_H
 #define RULESETS_ENTITY_H
 
-#include "attributes.h"
 #include "LocatedEntity.h"
 
 #include "modules/Location.h"
 
 #include "common/BaseWorld.h"
+#include "common/Property.h"
 
 #include <iostream>
 
 class Motion;
 
-/// \brief Classes that model in world entities
-///
-/// These classes are used to model all in world entities or objects.
-/// \defgroup EntityClasses In World Entity Classes
+/// \brief Flag indicating entity has been written to permanent store
+/// \ingroup EntityFlags
+static const unsigned int entity_clean = 1 << 0;
+/// \brief Flag indicating entity POS has been written to permanent store
+/// \ingroup EntityFlags
+static const unsigned int entity_pos_clean = 1 << 1;
+/// \brief Flag indicating entity ORIENT has been written to permanent store
+/// \ingroup EntityFlags
+static const unsigned int entity_orient_clean = 1 << 2;
+
+static const unsigned int entity_clean_mask = entity_clean |
+                                              entity_pos_clean |
+                                              entity_orient_clean;
+
+/// \brief Flag indicating entity is perceptive
+/// \ingroup EntityFlags
+static const unsigned int entity_perceptive = 1 << 3;
+/// \brief Flag indicating entity has been destroyed
+/// \ingroup EntityFlags
+static const unsigned int entity_destroyed = 1 << 4;
+/// \brief Flag indicating entity has been queued for storage update
+/// \ingroup EntityFlags
+static const unsigned int entity_queued = 1 << 5;
+/// \brief Flag indicaiting entity is ephemeral
+/// \ingroup EntityFlags
+static const unsigned int entity_ephem = 1 << 6;
 
 /// \brief This is the base class from which all in-game objects inherit.
 ///
@@ -46,29 +68,18 @@ class Motion;
 /// It implements the basic types required for persistance.
 /// \ingroup EntityClasses
 class Entity : public LocatedEntity {
-  private:
-    /// Flag indicating that this entity has been destroyed
-    bool m_destroyed;
   protected:
     /// Motion behavoir of this entity
     Motion * m_motion;
     /// Map of operation handlers
     HandlerMap m_operationHandlers;
-
-    /// Is this perceptive
-    bool m_perceptive;
-  public:
     /// Flags indicating changes to attributes
-    unsigned int m_update_flags;
+    unsigned int m_flags;
 
+  public:
     explicit Entity(const std::string & id, long intId);
     virtual ~Entity();
 
-    /// \brief Check if this entity is flagged as destroyed
-    bool isDestroyed() const {
-        return m_destroyed;
-    }
-
     /// \brief Accessor for pointer to motion object
     Motion * motion() const {
         return m_motion;
@@ -83,20 +94,86 @@ class Entity : public LocatedEntity {
         BaseWorld::instance().message(op, *this);
     }
 
-    /// \brief Accessor for update flags
-    const int getUpdateFlags() const { return m_update_flags; }
-
     /// \brief Check if this entity is flagged as perceptive
-    const bool isPerceptive() const { return m_perceptive; }
+    const bool isPerceptive() const { return m_flags & entity_perceptive; }
 
-    /// \brief Reset the update flags
-    void clearUpdateFlags() { m_update_flags = 0; }
+    /// \brief Check if this entity is flagged as destroyed
+    bool isDestroyed() const { return m_flags & entity_destroyed; }
+
+    /// \brief Accessor for flags
+    const int getFlags() const { return m_flags; }
+
+    void setFlags(unsigned int flags) { m_flags |= flags; }
+
+    void resetFlags(unsigned int flags) { m_flags &= ~flags; }
 
     virtual void setAttr(const std::string & name,
                          const Atlas::Message::Element &);
+    virtual const PropertyBase * getProperty(const std::string & name) const;
 
+    PropertyBase * modProperty(const std::string & name);
     void setProperty(const std::string & name, PropertyBase * prop);
 
+    /// \brief Get a property that is required to of a given type.
+    template <class PropertyT>
+    PropertyT * modPropertyClass(const std::string & name)
+    {
+        PropertyBase * p = modProperty(name);
+        if (p != 0) {
+            return dynamic_cast<PropertyT *>(p);
+        }
+        return 0;
+    }
+
+    /// \brief Get a modifiable property that is a generic property of a type
+    ///
+    /// If the property is not set on the Entity instance, but has a class
+    /// default, the default is copied to the instance, and a pointer is
+    /// returned if it is a property of the right type.
+    template <typename T>
+    Property<T> * modPropertyType(const std::string & name)
+    {
+        PropertyBase * p = modProperty(name);
+        if (p != 0) {
+            return dynamic_cast<Property<T> *>(p);
+        }
+        return 0;
+    }
+
+    /// \brief Require that a property of a given type is set.
+    ///
+    /// If the property is not set on the Entity instance, but has a class
+    /// default, the default is copied to the instance, and a pointer is
+    /// returned if it is a property of the right type. If it does not
+    /// exist, or is not of the right type, a new property is created of
+    /// the right type, and installed on the Entity instance.
+    template <class PropertyT>
+    PropertyT * requirePropertyClass(const std::string & name,
+                                     const Atlas::Message::Element & def_val
+                                     = Atlas::Message::Element())
+    {
+        PropertyBase * p = modProperty(name);
+        PropertyT * sp = 0;
+        if (p != 0) {
+            sp = dynamic_cast<PropertyT *>(p);
+        }
+        if (sp == 0) {
+            m_properties[name] = sp = new PropertyT;
+            if (p != 0) {
+                // If it is not of the right type, delete it and a new
+                // one of the right type will be inserted.
+                Atlas::Message::Element val;
+                if (p->get(val)) {
+                    sp->set(val);
+                }
+                delete p;
+            } else if (!def_val.isNone()) {
+                sp->set(def_val);
+            }
+        }
+        return sp;
+    }
+
     void installHandler(int, Handler);
 
     void destroy();
@@ -118,7 +195,6 @@ class Entity : public LocatedEntity {
     virtual void MoveOperation(const Operation &, OpVector &);
     virtual void NourishOperation(const Operation &, OpVector &);
     virtual void SetOperation(const Operation &, OpVector &);
-    virtual void SetupOperation(const Operation &, OpVector &);
     virtual void SightOperation(const Operation &, OpVector &);
     virtual void SoundOperation(const Operation &, OpVector &);
     virtual void TalkOperation(const Operation &, OpVector &);
@@ -133,6 +209,7 @@ class Entity : public LocatedEntity {
     void callOperation(const Operation &, OpVector &);
 
     virtual void onContainered();
+    virtual void onUpdated();
 
     /// Signal indicating that this entity has been changed
     sigc::signal<void> updated;
