@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: LocatedEntity.cpp,v 1.13 2008-01-28 23:48:32 alriddoch Exp $
+// $Id$
 
 #include "LocatedEntity.h"
 
@@ -48,13 +48,14 @@ const std::set<std::string> & LocatedEntity::immutables()
         m_immutable.insert("velocity");
         m_immutable.insert("orientation");
         m_immutable.insert("contains");
+        m_immutable.insert("objtype");
     }
     return m_immutable;
 }
 
 /// \brief LocatedEntity constructor
 LocatedEntity::LocatedEntity(const std::string & id, long intId) :
-               Identified(id, intId),
+               Router(id, intId),
                m_refCount(0), m_seq(0),
                m_script(&noScript), m_type(0), m_contains(0)
 {
@@ -115,6 +116,29 @@ bool LocatedEntity::getAttr(const std::string & name, Element & attr) const
     return false;
 }
 
+/// \brief Get the value of an attribute if it is the right type
+///
+/// @param name Name of attribute to be retrieved
+/// @param attr Reference used to store value
+/// @return trye if this entity has an attribute with the name given
+/// false otherwise
+bool LocatedEntity::getAttrType(const std::string & name,
+                                Element & attr,
+                                int type) const
+{
+    PropertyDict::const_iterator I = m_properties.find(name);
+    if (I != m_properties.end()) {
+        return I->second->get(attr) && attr.getType() == type;
+    }
+    if (m_type != 0) {
+        I = m_type->defaults().find(name);
+        if (I != m_type->defaults().end()) {
+            return I->second->get(attr) && attr.getType() == type;
+        }
+    }
+    return false;
+}
+
 /// \brief Set the value of an attribute
 ///
 /// @param name Name of attribute to be changed
@@ -135,7 +159,7 @@ void LocatedEntity::setAttr(const std::string & name, const Element & attr)
 /// @param name name of the attribute for which the property is required.
 /// @return a pointer to the property, or zero if the attributes does
 /// not exist, or is not stored using a property object.
-PropertyBase * LocatedEntity::getProperty(const std::string & name) const
+const PropertyBase * LocatedEntity::getProperty(const std::string & name) const
 {
     PropertyDict::const_iterator I = m_properties.find(name);
     if (I != m_properties.end()) {
@@ -150,6 +174,12 @@ void LocatedEntity::onContainered()
 {
 }
 
+/// \brief Called when the properties of this entity change.
+///
+void LocatedEntity::onUpdated()
+{
+}
+
 /// \brief Associate a script with this entity
 ///
 /// The previously associated script is deleted.
@@ -180,23 +210,18 @@ void LocatedEntity::makeContainer()
 /// container.
 void LocatedEntity::changeContainer(LocatedEntity * new_loc)
 {
+    assert(m_location.m_loc != 0);
     assert(m_location.m_loc->m_contains != 0);
     m_location.m_loc->m_contains->erase(this);
-#if 0
     if (m_location.m_loc->m_contains->empty()) {
-        m_location.m_loc->m_update_flags |= a_cont;
-        m_location.m_loc->updated.emit();
+        m_location.m_loc->onUpdated();
     }
-#endif
     new_loc->makeContainer();
     bool was_empty = new_loc->m_contains->empty();
     new_loc->m_contains->insert(this);
-#if 0
     if (was_empty) {
-        new_loc->m_update_flags |= a_cont;
-        new_loc->updated.emit();
+        new_loc->onUpdated();
     }
-#endif
     assert(m_location.m_loc->checkRef() > 0);
     m_location.m_loc->decRef();
     m_location.m_loc = new_loc;
@@ -204,9 +229,6 @@ void LocatedEntity::changeContainer(LocatedEntity * new_loc)
     assert(m_location.m_loc->checkRef() > 0);
 
     onContainered();
-#if 0
-    m_update_flags |= a_loc;
-#endif
 }
 
 /// \brief Read attributes from an Atlas element
