@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: MemMap.cpp,v 1.105 2008-01-05 14:05:05 alriddoch Exp $
+// $Id$
 
 #include "MemMap.h"
 
@@ -27,7 +27,7 @@
 #include "common/debug.h"
 #include "common/TypeNode.h"
 #include "common/compose.hpp"
-#include "common/inheritance.h"
+#include "common/Inheritance.h"
 
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
@@ -92,6 +92,7 @@ void MemMap::readEntity(MemEntity * entity, const RootEntity & ent)
         // Has LOC been changed?
         if (old_loc == 0 || new_loc_id != old_loc->getId()) {
             entity->m_location.m_loc = getAdd(new_loc_id);
+            assert(0 != entity->m_location.m_loc);
             assert(old_loc != entity->m_location.m_loc);
             if (old_loc != 0) {
                 assert(old_loc->m_contains != 0);
@@ -140,7 +141,8 @@ MemEntity * MemMap::newEntity(const std::string & id, long int_id,
 MemMap::MemMap(Script *& s) : m_checkIterator(m_entities.begin()), m_script(s)
 {
     if (m_entity_type == 0) {
-        m_entity_type = Inheritance::instance().getType("game_entity");
+        // m_entity_type = Inheritance::instance().getType("game_entity");
+        m_entity_type = new TypeNode();
         assert(m_entity_type != 0);
     }
 }
