@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: PythonArithmeticScript.cpp,v 1.7 2006-12-24 17:18:55 alriddoch Exp $
+// $Id$
 
 #include <Python.h>
 
@@ -40,9 +40,9 @@ PythonArithmeticScript::~PythonArithmeticScript()
 
 int PythonArithmeticScript::attribute(const std::string & name, float & val)
 {
-    PyObject * py_name = PyString_FromString(name.c_str());
-    PyObject * ret = PyObject_CallMethod(m_script, "attribute", "(O)", py_name);
-    Py_DECREF(py_name);
+    PyObject * pn = PyString_FromString(name.c_str());
+    PyObject * ret = PyObject_GenericGetAttr(m_script, pn);
+    Py_DECREF(pn);
     if (ret == NULL) {
         if (PyErr_Occurred() == NULL) {
             // std::cout << "No attribute method" << std::endl << std::flush;
@@ -64,3 +64,12 @@ int PythonArithmeticScript::attribute(const std::string & name, float & val)
     }
     return 0;
 }
+
+void PythonArithmeticScript::set(const std::string & name, const float & val)
+{
+    PyObject * pn = PyString_FromString(name.c_str());
+    PyObject * py_val = PyFloat_FromDouble(val);
+    PyObject_GenericSetAttr(m_script, pn, py_val);
+    Py_DECREF(pn);
+    Py_DECREF(py_val);
+}
