@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Stackable.cpp,v 1.55 2008-01-26 17:43:22 alriddoch Exp $
+// $Id$
 
 // A stackable object, ie one which can represent multiple object of the
 // same type. Used for things like coins.
@@ -44,11 +44,10 @@ using Atlas::Objects::Entity::Anonymous;
 /// @param id identifier of this Entity
 /// @param intId identifier of this Entity
 Stackable::Stackable(const std::string & id, long intId) :
-           Identified(id, intId),
            Stackable_parent(id, intId),
                                              m_num(1)
 {
-    m_properties["num"] = new Property<int>(m_num, 0);
+    // m_properties["num"] = new Property<int>(m_num, 0);
 }
 
 Stackable::~Stackable()
@@ -57,7 +56,6 @@ Stackable::~Stackable()
 
 void Stackable::CombineOperation(const Operation & op, OpVector & res)
 {
-    std::cout << "CombineOperation" << std::endl << std::flush;
     int old_num = m_num;
     const std::vector<Root> & args = op->getArgs();
     std::vector<Root>::const_iterator Iend = args.end();
