@@ -15,11 +15,10 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Thing.cpp,v 1.228 2008-01-26 17:43:22 alriddoch Exp $
+// $Id$
 
 #include "Thing.h"
 
-#include "Script.h"
 #include "Motion.h"
 
 #include "common/log.h"
@@ -62,7 +61,6 @@ static const bool debug_flag = false;
 
 /// \brief Constructor for physical or tangiable entities.
 Thing::Thing(const std::string & id, long intId) :
-       Identified(id, intId),
        Thing_parent(id, intId)
 {
     m_motion = new Motion(*this);
@@ -231,7 +229,7 @@ void Thing::MoveOperation(const Operation & op, OpVector & res)
                                                     m_location.pos(),
                                                     mode);
     m_location.update(current_time);
-    m_update_flags |= a_pos;
+    m_flags &= ~(entity_pos_clean | entity_clean);
 
     if (ent->hasAttrFlag(Atlas::Objects::Entity::VELOCITY_FLAG)) {
         // Update velocity
@@ -243,7 +241,7 @@ void Thing::MoveOperation(const Operation & op, OpVector & res)
     if (ent->copyAttr("orientation", attr_orientation) == 0) {
         // Update orientation
         m_location.m_orientation.fromAtlas(attr_orientation.asList());
-        m_update_flags |= a_orient;
+        m_flags &= ~entity_orient_clean;
     }
 
     // At this point the Location data for this entity has been updated.
@@ -310,7 +308,8 @@ void Thing::MoveOperation(const Operation & op, OpVector & res)
         checkVisibility(old_pos, res);
     }
     m_seq++;
-    updated.emit();
+
+    onUpdated();
 }
 
 /// \brief Check changes in visibility of this entity
@@ -419,8 +418,8 @@ void Thing::SetOperation(const Operation & op, OpVector & res)
     s->setArgs1(op);
     res.push_back(s);
     m_seq++;
-    if (m_update_flags != 0) {
-        updated.emit();
+    if (~m_flags & entity_clean) {
+        onUpdated();
     }
 }
 
@@ -437,60 +436,35 @@ void Thing::SetOperation(const Operation & op, OpVector & res)
 /// place.
 /// @param op Update operation that notifies of the changes.
 /// @param res The result of the operation is returned here.
-void Thing::updateProperties(const Operation & op, OpVector & res) const
+void Thing::updateProperties(const Operation & op, OpVector & res)
 {
-    const std::vector<Root> & args = op->getArgs();
-    if (args.empty()) {
-       return;
-    }
-
-    RootEntity arg = smart_dynamic_cast<RootEntity>(args.front());
-    if (!arg.isValid()) {
-        error(op, "Update op has malformed args", res, getId());
-        return;
-    }
-
     debug(std::cout << "Generating property update" << std::endl << std::flush;);
 
     Anonymous set_arg;
     set_arg->setId(getId());
 
-    // Check if any of the hard attributes on RootEntity of changed.
-    // All other hard attributes cannot be changed this way. Location related
-    // attrs can only be changed by a Move or move relate update.
-    // ID and PARENTS are immutable.
-    if (!arg->isDefaultName()) {
-        // Update the name
-        // FIXME How?
-    }
-    if (!arg->isDefaultContains()) {
-        // Update the contains
-        // FIXME Really?
-        // Surely better to go through the Property?
-    }
-
-    // FIXME SLOW!
-    MapType attrs = arg->asMessage();
-    MapType::const_iterator I = attrs.begin();
-    MapType::const_iterator Iend = attrs.end();
-
-    PropertyDict::const_iterator J;
+    PropertyDict::const_iterator J = m_properties.begin();
     PropertyDict::const_iterator Jend = m_properties.end();
 
-    for (; I != Iend; ++I) {
-        const std::string & attr = I->first;
-        debug(std::cout << "  " << attr << std::endl << std::flush;);
+    for (; J != Jend; ++J) {
+        PropertyBase * prop = J->second;
+        assert(prop != 0);
+        if (prop->flags() & flag_unsent) {
+            debug(std::cout << "UPDATE:  " << flag_unsent << " " << J->first
+                            << std::endl << std::flush;);
 
-        J = m_properties.find(attr);
-        if (J != Jend) {
-            // Dump the property value into the Sight(Set()) arg
-            J->second->add(attr, set_arg);
-        } else {
-            error(op, String::compose("Got update for non-existant property "
-                                      "\"%1\"", attr), res, getId());
+            prop->add(J->first, set_arg);
+            prop->resetFlags(flag_unsent | per_clean);
+            resetFlags(entity_clean);
+            // FIXME Make sure we handle separately for private properties
         }
     }
 
+    m_seq++;
+    if (~m_flags & entity_clean) {
+        onUpdated();
+    }
+
     Set set;
     set->setTo(getId());
     set->setFrom(getId());
@@ -584,7 +558,7 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
                                                     m_location.pos(),
                                                     mode);
     m_location.update(current_time);
-    m_update_flags |= a_pos;
+    m_flags &= ~(entity_pos_clean | entity_clean);
 
     float update_time = consts::move_tick;
 
@@ -644,7 +618,7 @@ void Thing::UpdateOperation(const Operation & op, OpVector & res)
     if (isPerceptive()) {
         checkVisibility(old_pos, res);
     }
-    updated.emit();
+    onUpdated();
 }
 
 void Thing::LookOperation(const Operation & op, OpVector & res)
