@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: World.cpp,v 1.115 2008-01-26 17:43:22 alriddoch Exp $
+// $Id$
 
 #include "World.h"
 
@@ -25,7 +25,8 @@
 #include "common/log.h"
 #include "common/const.h"
 #include "common/debug.h"
-#include "common/inheritance.h"
+#include "common/Inheritance.h"
+#include "common/compose.hpp"
 
 #include "common/Eat.h"
 #include "common/Nourish.h"
@@ -66,13 +67,12 @@ typedef enum { ROCK = 0, SAND = 1, GRASS = 2, SILT = 3, SNOW = 4} Surface;
 
 /// \brief Constructor for the World entity
 World::World(const std::string & id, long intId) :
-       Identified(id, intId),
        World_parent(id, intId),
            m_terrain(*new Mercator::Terrain(Mercator::Terrain::SHADED)),
            m_tileShader(*new Mercator::TileShader)
 {
     m_properties["terrain"] = new TerrainProperty(m_terrain, m_modifiedTerrain,
-                                                  m_modifiedTerrain, a_terrain);
+                                                  m_modifiedTerrain, 0);
     m_properties["calendar"] = new CalendarProperty(0);
 
     m_tileShader.addShader(new Mercator::FillShader(), ROCK);
@@ -116,8 +116,8 @@ int World::getSurface(const Point3D & pos, int & material)
     if (!segment->isValid()) {
         segment->populate();
     }
-    x = x - segment->getResolution() * segment->getXRef();
-    y = y - segment->getResolution() * segment->getYRef();
+    x = x - segment->getXRef();
+    y = y - segment->getYRef();
     const Mercator::Segment::Surfacestore & surfaces = segment->getSurfaces();
     WFMath::Vector<3> normal;
     float height = -23;
@@ -143,7 +143,8 @@ void World::EatOperation(const Operation & op, OpVector & res)
     const std::string & from_id = op->getFrom();
     Entity * from = BaseWorld::instance().getEntity(from_id);
     if (from == 0) {
-        log(ERROR, "World got eat op from non-existant entity.");
+        log(ERROR, String::compose("World got eat op from non-existant "
+                                   "entity %1.", from_id));
         return;
     }
 
