@@ -10,6 +10,7 @@ import atlas
 
 
 class Apple(Seed):
+    """An apple which can be eaten, and ferment as it ages."""
     def eat_operation(self, op):
         ent=Entity(self.id,status=-1)
         res = Operation("set",ent,to=self)
@@ -17,11 +18,6 @@ class Apple(Seed):
         nour=Entity(to_,mass=self.mass,alcohol=self.alcohol)
         res = res + Operation("nourish",nour,to=to_)
         return res
-    def setup_operation(self, op):
-        # Decay a bit, we don't last forever
-        opTick=Operation("tick",to=self)
-        opTick.setFutureSeconds(900)
-        return opTick
     def tick_operation(self, op):
         # After a short while we turn into a rotten apple, which is alcoholic
         if self.alcohol > 0:
