@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Account.cpp,v 1.159 2008-01-28 23:48:32 alriddoch Exp $
+// $Id$
 
 #include "Account.h"
 
@@ -23,7 +23,7 @@
 #include "ServerRouting.h"
 #include "Lobby.h"
 #include "ExternalMind.h"
-#include "Persistance.h"
+#include "Persistence.h"
 
 #include "rulesets/Character.h"
 
@@ -32,7 +32,7 @@
 #include "common/const.h"
 #include "common/debug.h"
 #include "common/serialno.h"
-#include "common/inheritance.h"
+#include "common/Inheritance.h"
 #include "common/compose.hpp"
 
 #include <wfmath/atlasconv.h>
@@ -71,9 +71,8 @@ Account::Account(Connection * conn,
                  const std::string & passwd,
                  const std::string & id,
                  long intId) :
-         Identified(id, intId),
-         m_connection(conn), m_username(uname),
-                              m_password(passwd)
+         Router(id, intId),
+         m_connection(conn), m_username(uname), m_password(passwd)
 {
 }
 
@@ -88,13 +87,13 @@ void Account::characterDestroyed(long id)
 {
     m_charactersDict.erase(id);
     if (consts::enable_persistence) {
-        Persistance::instance()->delCharacter(String::compose("%1", id));
+        Persistence::instance()->delCharacter(String::compose("%1", id));
     }
 }
 
 /// \brief Add a Character to those that belong to this Account
 ///
-/// @param chr Character object to be added
+/// @param chr Character object to be adddded
 void Account::addCharacter(Entity * chr)
 {
     Character * pchar = dynamic_cast<Character *>(chr);
@@ -132,7 +131,7 @@ Entity * Account::addNewCharacter(const std::string & typestr,
         chr->destroyed.connect(sigc::bind(sigc::mem_fun(this, &Account::characterDestroyed), chr->getIntId()));
         m_connection->addEntity(chr);
         if (consts::enable_persistence) {
-            Persistance::instance()->addCharacter(*this, *chr);
+            Persistence::instance()->addCharacter(*this, *chr);
         }
 
         // Hack in default objects
@@ -141,7 +140,6 @@ Entity * Account::addNewCharacter(const std::string & typestr,
         create_arg->setParents(std::list<std::string>(1,"coin"));
         ::addToEntity(Point3D(0,0,0), create_arg->modifyPos());
         create_arg->setLoc(chr->getId());
-        create_arg->setName("coin");
         // FIXME We can probably send the same op 10 times, rather than create 10
         // FIXME alternatively we can set 10 args on one op
         for(int i = 0; i < 10; i++) {
@@ -153,7 +151,6 @@ Entity * Account::addNewCharacter(const std::string & typestr,
 
         create_arg = create_arg.copy();
         create_arg->setParents(std::list<std::string>(1, "shirt"));
-        create_arg->setName("shirt");
         Create c;
         c->setTo(chr->getId());
         c->setArgs1(create_arg);
@@ -161,7 +158,6 @@ Entity * Account::addNewCharacter(const std::string & typestr,
 
         create_arg = create_arg.copy();
         create_arg->setParents(std::list<std::string>(1, "trousers"));
-        create_arg->setName("trousers");
         c = Create();
         c->setTo(chr->getId());
         c->setArgs1(create_arg);
@@ -169,7 +165,6 @@ Entity * Account::addNewCharacter(const std::string & typestr,
 
         create_arg = create_arg.copy();
         create_arg->setParents(std::list<std::string>(1, "cloak"));
-        create_arg->setName("cloak");
         c = Create();
         c->setTo(chr->getId());
         c->setArgs1(create_arg);
@@ -177,7 +172,6 @@ Entity * Account::addNewCharacter(const std::string & typestr,
 
         create_arg = create_arg.copy();
         create_arg->setParents(std::list<std::string>(1, "boots"));
-        create_arg->setName("boots");
         c = Create();
         c->setTo(chr->getId());
         c->setArgs1(create_arg);
@@ -185,7 +179,6 @@ Entity * Account::addNewCharacter(const std::string & typestr,
 
         create_arg = create_arg.copy();
         create_arg->setParents(std::list<std::string>(1, "hat"));
-        create_arg->setName("hat");
         c = Create();
         c->setTo(chr->getId());
         c->setArgs1(create_arg);
@@ -337,6 +330,7 @@ void Account::CreateOperation(const Operation & op, OpVector & res)
     Anonymous new_character;
     new_character->setParents(std::list<std::string>(1, typestr));
     new_character->setAttr("status", 0.024);
+    new_character->setAttr("mind", "");
     if (!arg->isDefaultName()) {
         new_character->setName(arg->getName());
     }
