@@ -15,15 +15,16 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Admin.cpp,v 1.121 2008-01-28 23:48:32 alriddoch Exp $
+// $Id$
 
 #include "Admin.h"
 
 #include "ServerRouting.h"
 #include "Connection.h"
-#include "EntityFactory.h"
+#include "EntityBuilder.h"
 #include "CommPeer.h"
 #include "CommServer.h"
+#include "Peer.h"
 
 #include "rulesets/Entity.h"
 
@@ -31,7 +32,7 @@
 #include "common/log.h"
 #include "common/debug.h"
 #include "common/serialno.h"
-#include "common/inheritance.h"
+#include "common/Inheritance.h"
 #include "common/compose.hpp"
 
 #include "common/Connect.h"
@@ -60,7 +61,6 @@ Admin::Admin(Connection * conn,
              const std::string & passwd,
              const std::string & id,
              long intId) :
-       Identified(id, intId),
        Account(conn, username, passwd, id, intId)
 {
 }
@@ -178,7 +178,7 @@ void Admin::LogoutOperation(const Operation & op, OpVector & res)
     if (account_id == getId()) {
        Account::LogoutOperation(op, res);
     }
-    IdentifiedRouter * account = m_connection->m_server.getObject(account_id);
+    Router * account = m_connection->m_server.getObject(account_id);
     if (!account) {
         error(op, "Logout failed", res, getId());
         return;
@@ -219,7 +219,7 @@ void Admin::GetOperation(const Operation & op, OpVector & res)
         EntityDict::const_iterator K = worldDict.find(intId);
 
         if (J != OOGDict.end()) {
-            IdentifiedRouter * obj = J->second;
+            Router * obj = J->second;
             Anonymous info_arg;
             obj->addToEntity(info_arg);
             info->setArgs1(info_arg);
@@ -404,15 +404,15 @@ void Admin::customConnectOperation(const Operation & op, OpVector & res)
         return;
     }
 
-    CommPeer * cp = new CommPeer(m_connection->m_commClient.m_commServer,
-                                 hostname, peerId);
+    CommPeer * cp = new CommPeer(m_connection->m_commClient.m_commServer);
     std::cout << "Connecting to " << hostname << std::endl << std::flush;
     if (cp->connect(hostname) != 0) {
         error(op, "Connection failed", res, getId());
         return;
     }
     log(INFO, "Connection succeeded");
-    cp->setup();
+    cp->setup(new Peer(*cp, m_connection->m_server,
+                       hostname, peerId));
     m_connection->m_commClient.m_commServer.addSocket(cp);
     // Fix it up
 }
