@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: CommMetaClient.h,v 1.16 2006-12-22 02:14:44 alriddoch Exp $
+// $Id$
 
 #ifndef SERVER_COMM_META_CLIENT_H
 #define SERVER_COMM_META_CLIENT_H
@@ -33,12 +33,22 @@ class CommMetaClient : public CommSocket, virtual public Idle {
   private:
     /// C++ iostream compatible socket object handling the socket IO.
     udp_socket_stream m_clientIos;
+
+    /// The domain of the metaserver to use.
+    std::string m_server;
+
+    /// The last time the address of the metaserver was successfully resolved
+    time_t m_resolveTime;
+
     /// The last time a packet was sent to the metaserver.
     time_t m_lastTime;
 
     /// Port number used to talk to the metaserver.
     static const int m_metaserverPort = 8453;
 
+    /// State of the client code.
+    enum { META_INIT, META_RESOLVED } m_state;
+
   public:
     explicit CommMetaClient(CommServer & svr);
 
