@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: CommServer.cpp,v 1.62 2008-04-28 17:26:10 alriddoch Exp $
+// $Id$
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
@@ -52,18 +52,6 @@ static const bool debug_flag = false;
 /// server object.
 CommServer::CommServer(ServerRouting & svr) : m_congested(false), m_server(svr)
 {
-#ifdef HAVE_EPOLL_CREATE
-    // 64 seems like a suitable value for initial number of sockets to be
-    // handled, though there is very little documentation on what would be
-    // a good choice here.
-    m_epollFd = epoll_create(64);
-    if (m_epollFd < 0) {
-        log(CRITICAL, String::compose("epoll_create: %s", strerror(errno)));
-        exit_flag = true;
-    }
-#endif // HAVE_EPOLL_CREATE
-    // Initialise the time
-    gettimeofday(&m_timeVal, NULL);
 }
 
 CommServer::~CommServer()
@@ -77,6 +65,23 @@ CommServer::~CommServer()
     }
 }
 
+int CommServer::setup()
+{
+#ifdef HAVE_EPOLL_CREATE
+    // 64 seems like a suitable value for initial number of sockets to be
+    // handled, though there is very little documentation on what would be
+    // a good choice here.
+    m_epollFd = epoll_create(64);
+    if (m_epollFd < 0) {
+        log(CRITICAL, String::compose("epoll_create: %s", strerror(errno)));
+        return -1;
+    }
+#endif // HAVE_EPOLL_CREATE
+    // Initialise the time
+    gettimeofday(&m_timeVal, NULL);
+    return 0;
+}
+
 /// \brief Idle function called from the main loop.
 ///
 /// Poll all the Idle objects that want to be polled regularly,
@@ -139,7 +144,7 @@ void CommServer::poll()
         return;
     }
 
-    m_congested = (rval != 0) || m_congested && busy;
+    m_congested = (rval != 0) || (m_congested && busy);
 
     if (rval == max_events) {
         // If we see this alot, we should increase the maximum
