@@ -15,12 +15,17 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: ExternalMind.cpp,v 1.23 2008-01-28 23:48:32 alriddoch Exp $
+// $Id$
 
 #include "ExternalMind.h"
 
 #include "Connection_methods.h"
 
+#include "rulesets/Entity.h"
+
+#include "common/log.h"
+#include "common/compose.hpp"
+
 #include <Atlas/Objects/SmartPtr.h>
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
@@ -31,12 +36,37 @@ using Atlas::Objects::smart_dynamic_cast;
 using Atlas::Objects::Entity::RootEntity;
 using Atlas::Objects::Entity::Anonymous;
 using Atlas::Objects::Operation::Sight;
+using Atlas::Objects::Operation::Delete;
 using Atlas::Objects::Operation::Imaginary;
 
-ExternalMind::ExternalMind(Connection & connection,
-                           const std::string & id,
-                           long intId) :
-              Identified(id, intId), m_connection(connection)
+static const double character_expire_time = 60 * 60; // 1 hour
+
+void ExternalMind::deleteEntity(const std::string & id)
+{
+    Delete d;
+    Anonymous del_arg;
+    del_arg->setId(id);
+    d->setArgs1(del_arg);
+    d->setTo(id);
+    m_entity.sendWorld(d);
+}
+
+void ExternalMind::purgeEntity(const LocatedEntity & ent)
+{
+    if (ent.m_contains != 0) {
+        LocatedEntitySet::const_iterator I = ent.m_contains->begin();
+        LocatedEntitySet::const_iterator Iend = ent.m_contains->end();
+        for (; I != Iend; ++I) {
+            LocatedEntity * child = *I;
+            assert(child != 0);
+            purgeEntity(*child);
+        }
+    }
+    deleteEntity(ent.getId());
+}
+
+ExternalMind::ExternalMind(Entity & e) : Router(e.getId(), e.getIntId()),
+                                         m_connection(0), m_entity(e)
 {
 }
 
@@ -47,9 +77,27 @@ ExternalMind::~ExternalMind()
     // m_connection.removeObject(getIntId());
 }
 
-void ExternalMind::operation(const Operation & op, OpVector &)
+void ExternalMind::operation(const Operation & op, OpVector & res)
 {
-    m_connection.send(op);
+    if (m_connection == 0) {
+        if (m_entity.getFlags() & entity_ephem) {
+            // If this entity no longer has a connection, and is ephemeral
+            // we should delete it.
+            if (op->getClassNo() != Atlas::Objects::Operation::DELETE_NO) {
+                purgeEntity(m_entity);
+            }
+        }
+        // std::cout << "Time since disco "
+                  // << BaseWorld::instance().getTime() - m_lossTime
+                  // << std::endl << std::flush;
+        if (BaseWorld::instance().getTime() - m_lossTime > character_expire_time) {
+            if (op->getClassNo() != Atlas::Objects::Operation::DELETE_NO) {
+                purgeEntity(m_entity);
+            }
+        }
+        return;
+    }
+    m_connection->send(op);
 
     // Here we see if there is anything we should be sending the user
     // extra info about. The initial demo implementation checks for
@@ -85,9 +133,23 @@ void ExternalMind::operation(const Operation & op, OpVector &)
                     sight->setFrom(getId());
                     sight->setArgs1(imaginary);
 
-                    m_connection.send(sight);
+                    m_connection->send(sight);
                 }
             }
         }
     }
 }
+
+const std::string & ExternalMind::connectionId()
+{
+    assert(m_connection != 0);
+    return m_connection->getId();
+}
+
+void ExternalMind::connect(Connection * c)
+{
+    m_connection = c;
+    if (c == 0) {
+        m_lossTime = BaseWorld::instance().getTime();
+    }
+}
