@@ -15,28 +15,43 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: ExternalMind.h,v 1.15 2008-01-28 23:48:32 alriddoch Exp $
+// $Id$
 
 #ifndef SERVER_EXTERNAL_MIND_H
 #define SERVER_EXTERNAL_MIND_H
 
-#include "common/Identified.h"
+#include "common/Router.h"
 
 class Connection;
+class Entity;
+class LocatedEntity;
 
 /// \brief This class connects in-game entities to the Connection of the client
 /// controlling it.
 ///
 /// Essentially used to relay in-game operations that pass to the mind on
 /// to the client.
-class ExternalMind : public IdentifiedRouter {
-  public:
-    Connection & m_connection;
+class ExternalMind : public Router {
+  protected:
+    Connection * m_connection;
+    Entity & m_entity;
+    double m_lossTime;
 
-    ExternalMind(Connection & connection, const std::string & id, long intId);
+    void deleteEntity(const std::string & id);
+    void purgeEntity(const LocatedEntity & ent);
+  public:
+
+    ExternalMind(Entity &);
     virtual ~ExternalMind();
 
     virtual void operation(const Operation &, OpVector &);
+
+    bool isConnected() { return m_connection != 0; }
+    bool isConnectedTo(Connection * c) { return m_connection == c; }
+
+    const std::string & connectionId();
+
+    void connect(Connection * c);
 };
 
 #endif // SERVER_EXTERNAL_MIND_H
