@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: ServerRouting.cpp,v 1.68 2008-01-28 23:48:33 alriddoch Exp $
+// $Id$
 
 #include "ServerRouting.h"
 #include "Lobby.h"
@@ -23,6 +23,8 @@
 #include "common/debug.h"
 #include "common/const.h"
 #include "common/BaseWorld.h"
+#include "common/Monitors.h"
+#include "common/compose.hpp"
 
 #include <Atlas/Message/Element.h>
 #include <Atlas/Objects/SmartPtr.h>
@@ -34,7 +36,8 @@ using Atlas::Message::MapType;
 using Atlas::Message::ListType;
 using Atlas::Objects::Entity::RootEntity;
 
-static bool debug_flag = false;
+BOOL_OPTION(restricted_flag, false, CYPHESIS, "restricted",
+            "Flag to control restricted mode");
 
 /// \brief Constructor for server object.
 ///
@@ -45,9 +48,21 @@ ServerRouting::ServerRouting(BaseWorld & wrld,
                              const std::string & name,
                              const std::string & id, long intId,
                              const std::string & lId, long lIntId) :
-        Identified(id, intId), m_svrRuleset(ruleset), m_svrName(name),
+        Router(id, intId),
+        m_svrRuleset(ruleset), m_svrName(name),
         m_numClients(0), m_world(wrld), m_lobby(*new Lobby(*this, lId, lIntId))
 {
+    Monitors * monitors = Monitors::instance();
+    monitors->insert("server", "cyphesis");
+    monitors->insert("builddate", String::compose("%1, %2",
+                                                  consts::buildDate,
+                                                  consts::buildTime));
+    monitors->watch("instance", new Monitor<std::string>(::instance));
+    monitors->watch("name", new Monitor<std::string>(m_svrName));
+    monitors->watch("ruleset", new Monitor<std::string>(m_svrRuleset));
+    monitors->watch("version", new Monitor<const char *>(consts::version));
+    monitors->watch("buildid", new Monitor<int>(consts::buildId));
+    monitors->watch("clients", new Monitor<int>(m_numClients));
 }
 
 /// Server destructor, implicitly destroys all OOG objects in the server.
