@@ -15,12 +15,12 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: SlaveClientConnection.h,v 1.5 2008-01-28 23:48:33 alriddoch Exp $
+// $Id$
 
 #ifndef SERVER_SLAVE_CLIENT_CONNECTION_H
 #define SERVER_SLAVE_CLIENT_CONNECTION_H
 
-#include "common/Identified.h"
+#include "common/Router.h"
 
 class CommClient;
 class ServerRouting;
@@ -30,15 +30,17 @@ class ServerRouting;
 ///
 /// This behaves much like Connection, but handles the different behavoir
 /// required because cyphesis is not the authoritative point for logins.
-class SlaveClientConnection : public IdentifiedRouter {
+class SlaveClientConnection : public Router {
   public:
     /// \brief network object the client is connected to
     CommClient & m_commClient;
     /// \brief core server object
     ServerRouting & m_server;
 
-    SlaveClientConnection(const std::string &, CommClient &, ServerRouting &);
+    SlaveClientConnection(CommClient &, ServerRouting &, const std::string & address, const std::string & id);
     virtual ~SlaveClientConnection();
+
+    virtual void operation(const Operation &, OpVector &);
 };
 
 #endif // SERVER_SLAVE_CLIENT_CONNECTION_H
