@@ -15,11 +15,11 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: WorldRouter.cpp,v 1.225 2008-01-05 14:05:06 alriddoch Exp $
+// $Id$
 
 #include "WorldRouter.h"
 
-#include "EntityFactory.h"
+#include "EntityBuilder.h"
 
 #include "rulesets/World.h"
 
@@ -33,9 +33,8 @@
 #include "common/TypeNode.h"
 #include "common/serialno.h"
 #include "common/compose.hpp"
-#include "common/inheritance.h"
-
-#include "common/Setup.h"
+#include "common/Inheritance.h"
+#include "common/Monitors.h"
 
 #include <Atlas/Objects/Operation.h>
 #include <Atlas/Objects/Anonymous.h>
@@ -44,7 +43,6 @@
 #include <algorithm>
 
 using Atlas::Message::Element;
-using Atlas::Objects::Operation::Setup;
 using Atlas::Objects::Operation::Appearance;
 using Atlas::Objects::Entity::RootEntity;
 using Atlas::Objects::Entity::Anonymous;
@@ -103,7 +101,9 @@ void WorldRouter::updateTime(int sec, int usec)
 /// Currently the world entity is included in the perceptives list,
 /// but I am not clear why. Need to look into why.
 WorldRouter::WorldRouter() : BaseWorld(*new World(consts::rootWorldId,
-                                                  consts::rootWorldIntId))
+                                                  consts::rootWorldIntId)),
+                             m_entityCount(1)
+          
 {
     struct timeval tv;
     gettimeofday(&tv, NULL);
@@ -115,6 +115,7 @@ WorldRouter::WorldRouter() : BaseWorld(*new World(consts::rootWorldId,
     m_eobjects[m_gameWorld.getIntId()] = &m_gameWorld;
     m_perceptives.insert(&m_gameWorld);
     //WorldTime tmp_date("612-1-1 08:57:00");
+    Monitors::instance()->watch("entities", new Monitor<int>(m_entityCount));
 }
 
 /// \brief Destructor for the world object.
@@ -239,12 +240,13 @@ float WorldRouter::constrainHeight(LocatedEntity * parent,
 /// the default spawn area if necessary. Handle inserting the
 /// entity into the loc/contains tree maintained by the Entity
 /// class. Send a Setup op to the entity.
-Entity * WorldRouter::addEntity(Entity * ent, bool setup)
+Entity * WorldRouter::addEntity(Entity * ent)
 {
     debug(std::cout << "WorldRouter::addEntity(Entity *)" << std::endl
                     << std::flush;);
     assert(ent->getIntId() != 0);
     m_eobjects[ent->getIntId()] = ent;
+    ++m_entityCount;
     assert(ent->m_location.isValid());
 
     if (!ent->m_location.isValid()) {
@@ -280,26 +282,21 @@ Entity * WorldRouter::addEntity(Entity * ent, bool setup)
     ent->m_location.m_loc->m_contains->insert(ent);
     ent->m_location.m_loc->incRef();
     if (cont_change) {
-        Entity * loc = dynamic_cast<Entity *>(ent->m_location.m_loc);
-        assert(loc != 0);
-        loc->m_update_flags |= a_cont;
-        loc->updated.emit();
+        // FIXME Mark the entity as dirty?
+        ent->onUpdated();
     }
     debug(std::cout << "Entity loc " << ent->m_location << std::endl
                     << std::flush;);
-    if (setup) {
-        Setup s;
-        s->setTo(ent->getId());
-        s->setFutureSeconds(-0.1);
-        message(s, m_gameWorld);
 
-        Anonymous arg;
-        Appearance app;
-        arg->setId(ent->getId());
-        arg->setStamp(ent->getSeq());
-        app->setArgs1(arg);
-        message(app, *ent);
-    }
+    Anonymous arg;
+    Appearance app;
+    arg->setId(ent->getId());
+    arg->setStamp(ent->getSeq());
+    app->setArgs1(arg);
+    message(app, *ent);
+
+    inserted.emit(ent);
+
     return ent;
 }
 
@@ -380,7 +377,9 @@ void WorldRouter::delEntity(Entity * ent)
     assert(ent->getIntId() != 0);
     m_perceptives.erase(ent);
     m_eobjects.erase(ent->getIntId());
+    --m_entityCount;
     ent->destroy();
+    ent->updated.emit();
     ent->decRef();
 }
 
