@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: WorldRouter.h,v 1.81 2008-01-13 01:32:55 alriddoch Exp $
+// $Id$
 
 #ifndef SERVER_WORLD_ROUTER_H
 #define SERVER_WORLD_ROUTER_H
@@ -71,6 +71,8 @@ class WorldRouter : public BaseWorld {
     time_t m_initTime;
     /// List of perceptive entities.
     EntitySet m_perceptives;
+    /// Count of in world entities
+    int m_entityCount;
 
     void addOperationToQueue(const Operation &, Entity &);
     Operation getOperationFromQueue();
@@ -83,7 +85,7 @@ class WorldRouter : public BaseWorld {
     virtual ~WorldRouter();
 
     bool idle(int, int);
-    Entity * addEntity(Entity * obj, bool setup = true);
+    Entity * addEntity(Entity * obj);
     Entity * addNewEntity(const std::string &, const Atlas::Objects::Entity::RootEntity &);
     Task * newTask(const std::string &, Character &);
     Task * activateTask(const std::string &, const std::string &,
@@ -98,6 +100,9 @@ class WorldRouter : public BaseWorld {
     virtual float constrainHeight(LocatedEntity * parent,
                                   const Point3D & pos,
                                   const std::string & mode);
+
+    /// \brief Signal that a new Entity has been inserted.
+    sigc::signal<void, Entity *> inserted;
 };
 
 #endif // SERVER_WORLD_ROUTER_H
