@@ -15,23 +15,28 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: server.cpp,v 1.159 2007-12-20 21:19:05 alriddoch Exp $
+// $Id$
 
 #ifdef HAVE_CONFIG_H
 #include "config.h"
 #endif
 
 #include "CommServer.h"
-#include "CommListener.h"
-#include "CommPeerListener.h"
+#include "CommTCPListener.h"
+#include "CommClientFactory.h"
 #include "CommUnixListener.h"
 #include "CommPSQLSocket.h"
 #include "CommMetaClient.h"
 #include "CommMDNSPublisher.h"
+#include "CommPeer.h"
 #include "ServerRouting.h"
-#include "EntityFactory.h"
-#include "Persistance.h"
+#include "EntityBuilder.h"
+#include "Persistence.h"
 #include "WorldRouter.h"
+#include "StorageManager.h"
+#include "IdleConnector.h"
+#include "UpdateTester.h"
+#include "Admin.h"
 #include "Admin.h"
 
 #include "rulesets/Python_API.h"
@@ -43,21 +48,42 @@
 #include "common/const.h"
 #include "common/debug.h"
 #include "common/globals.h"
-#include "common/inheritance.h"
+#include "common/Inheritance.h"
 #include "common/compose.hpp"
 #include "common/system.h"
 #include "common/nls.h"
+#include "common/sockets.h"
 
 #include <varconf/config.h>
 
+#include <sigc++/functors/mem_fun.h>
+
 #include <sstream>
 
+class TrustedConnection;
+class Peer;
+
 static const bool debug_flag = false;
 
+INT_OPTION(http_port_num, 6780, CYPHESIS, "httpport",
+           "Network listen port for http connection to the server");
+
+BOOL_OPTION(useMetaserver, true, CYPHESIS, "usemetaserver",
+            "Flag to control registration with the metaserver");
+
+STRING_OPTION(mserver, "metaserver.worldforge.org", CYPHESIS, "metaserver",
+              "Hostname to use as the metaserver");
+
+
 int main(int argc, char ** argv)
 {
+    if (security_init() != 0) {
+        log(CRITICAL, "Security initialisation Error. Exiting.");
+        return EXIT_SECURITY_ERROR;
+    }
+
     if (security_check() != SECURITY_OKAY) {
-        log(CRITICAL, "Security Error. Exiting.");
+        log(CRITICAL, "Security check error. Exiting.");
         return EXIT_SECURITY_ERROR;
     }
 
@@ -99,7 +125,7 @@ int main(int argc, char ** argv)
     // database support, this will open the various databases used to
     // store server data.
     if (database_flag) {
-        Persistance * p = Persistance::instance();
+        Persistence * p = Persistence::instance();
         int dbstatus = p->init();
         if (dbstatus < 0) {
             database_flag = false;
@@ -125,23 +151,15 @@ int main(int argc, char ** argv)
     // If the restricted flag is set in the config file, then we
     // don't allow connecting users to create accounts. Accounts must
     // be created manually by the server administrator.
-    if (readConfigItem(instance, "restricted", restricted_flag) == 0) {
-        if (restricted_flag) {
-            log(INFO, "Setting restricted mode.");
-        }
+    if (restricted_flag) {
+        log(INFO, "Setting restricted mode.");
     }
 
     readConfigItem(instance, "inittime", timeoffset);
 
-    bool useMetaserver = false;
-    readConfigItem(instance, "usemetaserver", useMetaserver);
-
-    std::string mserver("metaserver.worldforge.org");
-    readConfigItem(instance, "metaserver", mserver);
-
     std::string server_name;
     if (readConfigItem(instance, "servername", server_name) != 0) {
-        if (instance == "cyphesis") {
+        if (instance == CYPHESIS) {
             server_name = get_hostname();
         } else {
             server_name = instance;
@@ -165,6 +183,8 @@ int main(int argc, char ** argv)
 
     WorldRouter world;
 
+    StorageManager store(world);
+
     // This ID is currently generated every time, but should perhaps be
     // persistent in future.
     std::string server_id, lobby_id;
@@ -182,6 +202,11 @@ int main(int argc, char ** argv)
 
     CommServer commServer(server);
 
+    if (commServer.setup() != 0) {
+        log(CRITICAL, "Internal error setting up server infrastructure");
+        return EXIT_SOCKET_ERROR;
+    }
+
     // This is where we should restore the database, before
     // the listen sockets are open. Unlike earlier code, we are
     // attempting to construct the internal state from the database,
@@ -191,18 +216,23 @@ int main(int argc, char ** argv)
     if (database_flag) {
         // log(INFO, _("Restoring world from database..."));
 
+        store.restoreWorld();
         // FIXME Do the following steps.
-        // Read the world entity if any from the database.
-        // If there was none, set it up by calling EntityBuilder::initWorld()
+        // Read the world entity if any from the database, or set it up.
         // If it was there, make sure it did not get any of the wrong
         // position or orientation data.
+        store.initWorld();
 
         // log(INFO, _("Restored world."));
 
         CommPSQLSocket * dbsocket = new CommPSQLSocket(commServer,
-                                        Persistance::instance()->m_connection);
+                                        Persistence::instance()->m_connection);
         commServer.addSocket(dbsocket);
         commServer.addIdle(dbsocket);
+
+        IdleConnector * storage_idle = new IdleConnector(commServer);
+        storage_idle->idling.connect(sigc::mem_fun(&store, &StorageManager::tick));
+        commServer.addIdle(storage_idle);
     } else {
         std::string adminId;
         long intId = newId(adminId);
@@ -212,7 +242,12 @@ int main(int argc, char ** argv)
         server.addAccount(admin);
     }
 
-    CommListener * listener = new CommListener(commServer);
+    // Add the test object, and call it regularly so it can do what it does.
+    // UpdateTester * update_tester = new UpdateTester(commServer);
+    // commServer.addIdle(update_tester);
+
+    CommTCPListener * listener = new CommTCPListener(commServer,
+          *new CommClientFactory<Connection>());
     if (client_port_num < 0) {
         client_port_num = dynamic_port_start;
         for (; client_port_num <= dynamic_port_end; client_port_num++) {
@@ -221,8 +256,9 @@ int main(int argc, char ** argv)
             }
         }
         if (client_port_num > dynamic_port_end) {
-            log(ERROR, "Could not find free client listen socket. "
-                       "Init failed.");
+            log(ERROR, String::compose("Could not find free client listen "
+                                       "socket in range %1-%2. Init failed.",
+                                       dynamic_port_start, dynamic_port_end));
             log(INFO, String::compose("To allocate 8 more ports please run:"
                                       "\n\n    cyconfig "
                                       "--cyphesis:dynamic_port_end=%1\n\n",
@@ -238,22 +274,27 @@ int main(int argc, char ** argv)
                              client_port_num + 1, varconf::USER);
     } else {
         if (listener->setup(client_port_num) != 0) {
-            log(ERROR, "Could not create client listen socket. Init failed.");
+            log(ERROR, String::compose("Could not create client listen socket "
+                                       "on port %1. Init failed.",
+                                       client_port_num));
             return EXIT_SOCKET_ERROR;
         }
     }
     commServer.addSocket(listener);
 
-    CommPeerListener * peerListener = new CommPeerListener(commServer);
+    CommTCPListener * peerListener = new CommTCPListener(commServer,
+          *new CommClientFactory<Peer>());
     if (peerListener->setup(peer_port_num) != 0) {
-        log(ERROR, "Could not create peer listen socket.");
+        log(ERROR, String::compose("Could not create peer listen socket "
+                                   "on port %1.", peer_port_num));
         delete peerListener;
     } else {
         commServer.addSocket(peerListener);
     }
 
 #ifdef HAVE_SYS_UN_H
-    CommUnixListener * localListener = new CommUnixListener(commServer);
+    CommUnixListener * localListener = new CommUnixListener(commServer,
+          *new CommClientFactory<TrustedConnection>());
     if (localListener->setup(client_socket_name) != 0) {
         log(ERROR, String::compose("Could not create local listen socket "
                                    "with address \"%1\"",
@@ -262,12 +303,32 @@ int main(int argc, char ** argv)
     } else {
         commServer.addSocket(localListener);
     }
+
+    CommUnixListener * pythonListener = new CommUnixListener(commServer,
+          *new CommPythonClientFactory());
+    if (pythonListener->setup(python_socket_name) != 0) {
+        log(ERROR, String::compose("Could not create python listen socket "
+                                   "with address %1.",
+                                   pythonListener->getPath()));
+        delete pythonListener;
+    } else {
+        commServer.addSocket(pythonListener);
+    }
 #endif
 
+    CommTCPListener * httpListener = new CommTCPListener(commServer,
+          *new CommHttpClientFactory());
+    if (httpListener->setup(http_port_num) != 0) {
+        log(ERROR, String::compose("Could not create http listen socket on "
+                                   "port %1.", http_port_num));
+        delete httpListener;
+    } else {
+        commServer.addSocket(httpListener);
+    }
+
     if (useMetaserver) {
         CommMetaClient * cmc = new CommMetaClient(commServer);
         if (cmc->setup(mserver) == 0) {
-            commServer.addSocket(cmc);
             commServer.addIdle(cmc);
         } else {
             log(ERROR, "Error creating metaserver comm channel.");
@@ -286,7 +347,7 @@ int main(int argc, char ** argv)
         delete cmdns;
     }
 
-#endif // defined(HAVE_LIBHOWL)
+#endif // defined(HAVE_LIBHOWL) || defined(HAVE_AVAHI)
 
     // Configuration is now complete, and verified as somewhat sane, so
     // we save the updated user config.
@@ -329,7 +390,7 @@ int main(int argc, char ** argv)
       // cause the destruction of the server and world objects, and the entire
       // world contents
 
-    Persistance::instance()->shutdown();
+    Persistence::instance()->shutdown();
 
     EntityBuilder::instance()->flushFactories();
     EntityBuilder::del();
