@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: IGEntityExerciser.h,v 1.26 2008-01-17 19:53:39 alriddoch Exp $
+// $Id$
 
 #ifndef TESTS_IG_ENTITY_EXERCISER_H
 #define TESTS_IG_ENTITY_EXERCISER_H
@@ -27,6 +27,8 @@
 
 #include "rulesets/Motion.h"
 
+#include "common/TypeNode.h"
+
 #include <Atlas/Message/Element.h>
 
 template <class EntityType>
@@ -37,38 +39,18 @@ class IGEntityExerciser : public EntityExerciser<EntityType> {
         new TestPropertyManager;
         if (e.getIntId() == 0) {
             new TestWorld(e);
-            e.m_contains = new LocatedEntitySet;
         } else {
-            e.m_location.m_loc = new Entity("0", 0);
-            e.m_location.m_loc->m_contains = new LocatedEntitySet;
-            e.m_location.m_loc->m_contains->insert(&e);
+            assert(e.m_location.m_loc != 0);
             new TestWorld(*dynamic_cast<Entity*>(e.m_location.m_loc));
         }
         BaseWorld::instance().addEntity(&e);
     }
 
-    bool checkAttributes(const std::set<std::string> & attr_names);
     bool checkProperties(const std::set<std::string> & prop_names);
 
     void runOperations();
 };
 
-template <class EntityType>
-inline bool IGEntityExerciser<EntityType>::checkAttributes(const std::set<std::string> & attr_names)
-{
-    Atlas::Message::Element null;
-    std::set<std::string>::const_iterator I = attr_names.begin();
-    std::set<std::string>::const_iterator Iend = attr_names.end();
-    for (; I != Iend; ++I) {
-        if (!this->m_ent.getAttr(*I, null)) {
-            std::cerr << "Entity does not have \"" << *I << "\" attribute."
-                      << std::endl << std::flush;
-            return false;
-        }
-    }
-    return true;
-}
-
 template <class EntityType>
 inline bool IGEntityExerciser<EntityType>::checkProperties(const std::set<std::string> & prop_names)
 {
@@ -423,18 +405,6 @@ inline void IGEntityExerciser<EntityType>::runOperations()
         }
         this->flushOperations(ov);
     }
-    {
-        Atlas::Objects::Operation::Setup op;
-        this->dispatchOp(op);
-        OpVector ov;
-        this->m_ent.SetupOperation(op, ov);
-        this->flushOperations(ov);
-
-        Atlas::Objects::Entity::Anonymous setup_arg;
-        op->setArgs1(setup_arg);
-        this->m_ent.SetupOperation(op, ov);
-        this->flushOperations(ov);
-    }
     {
         Atlas::Objects::Operation::Appearance op;
         this->dispatchOp(op);
@@ -485,6 +455,7 @@ inline void IGEntityExerciser<EntityType>::runOperations()
         this->m_ent.UpdateOperation(op, ov);
         this->flushOperations(ov);
 
+        this->m_ent.m_location.m_pos = Point3D(0,0,0);
         this->m_ent.m_location.m_velocity = Vector3D(1,0,0);
         this->m_ent.UpdateOperation(op, ov);
         this->flushOperations(ov);
