@@ -15,7 +15,7 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: Planttest.cpp,v 1.14 2008-01-07 14:35:48 alriddoch Exp $
+// $Id$
 
 #include "IGEntityExerciser.h"
 #include "allOperations.h"
@@ -50,12 +50,6 @@ int main()
 
     std::set<std::string> attrNames;
     attrNames.insert("id");
-    attrNames.insert("bbox");
-    attrNames.insert("fruits");
-    attrNames.insert("radius");
-    attrNames.insert("fruitName");
-    attrNames.insert("fruitChance");
-    attrNames.insert("sizeAdult");
 
     // Make sure we have all the default attributes
     assert(ee.checkAttributes(attrNames));
@@ -96,7 +90,7 @@ int main()
     e.addToMessage(entityAsAtlas);
 
     // Make sure we got at least some of it
-    assert(entityAsAtlas.size() > 14);
+    assert(entityAsAtlas.size() > 13);
 
     // Read the contents of the Atlas Message back in
     e.merge(entityAsAtlas);
