@@ -15,10 +15,16 @@
 // along with this program; if not, write to the Free Software Foundation,
 // Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-// $Id: TestPropertyManager.cpp,v 1.2 2006-10-26 00:48:16 alriddoch Exp $
+// $Id$
 
 #include "TestPropertyManager.h"
 
+#include "common/Property.h"
+
+#include <Atlas/Message/Element.h>
+
+using Atlas::Message::Element;
+
 TestPropertyManager::TestPropertyManager()
 {
 }
@@ -27,8 +33,24 @@ TestPropertyManager::~TestPropertyManager()
 {
 }
 
-PropertyBase * TestPropertyManager::addProperty(Entity * entity,
-                                                const std::string & name)
+PropertyBase * TestPropertyManager::addProperty(const std::string & name,
+                                                int type)
 {
-    return 0;
+    PropertyBase * p = 0;
+    switch (type) {
+      case Element::TYPE_INT:
+        p = new Property<int>;
+        break;
+      case Element::TYPE_FLOAT:
+        p = new Property<double>;
+        break;
+      case Element::TYPE_STRING:
+        p = new Property<std::string>;
+        break;
+      default:
+        p = new SoftProperty;
+        break;
+    }
+
+    return p;
 }
